/* This file is part of adapta-gtk-theme Copyright (C) 2016-2018 Tista <tista.gma500@gmail.com> This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version. */
* { transition-property: border-color, border-image, background-color, background-image, box-shadow; transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1); transition-duration: 0.15s; }

*:focus { transition-duration: 0s; }

stage { font-size: 10pt; font-family: Roboto, Noto Sans, Sans-Serif; color: #CFD8DC; }

.button { border-color: transparent; color: rgba(207, 216, 220, 0.87); background-color: transparent; box-shadow: 0 0 transparent; text-shadow: none; icon-shadow: none; padding: 5px 12px 6px; border-radius: 2px; border-width: 0; font-weight: 500; }

.button:hover { border-color: transparent; color: #CFD8DC; background-color: rgba(207, 216, 220, 0.12); box-shadow: 0 0 transparent; text-shadow: none; icon-shadow: none; }

.button:active { border-color: transparent; color: #FFFFFF; background-color: rgba(207, 216, 220, 0.25); box-shadow: 0 0 transparent; text-shadow: none; icon-shadow: none; }

.button:insensitive { border-color: transparent; color: rgba(207, 216, 220, 0.2436); background-color: transparent; box-shadow: 0 0 transparent; text-shadow: none; icon-shadow: none; }

.button:focus { color: #CFD8DC; box-shadow: 0 0 transparent; text-shadow: none; icon-shadow: none; }

.modal-dialog-linked-button { padding: 6px 12px 7px; border: none; color: rgba(129, 196, 191, 0.87); background-color: transparent; box-shadow: 0 0 0 2px transparent; text-shadow: none; icon-shadow: none; font-weight: 500; }

.modal-dialog-linked-button:hover { color: #81c4bf; background-color: rgba(77, 182, 172, 0.12); }

.modal-dialog-linked-button:focus { color: #81c4bf; background-color: rgba(0, 0, 0, 0.01); box-shadow: inset 0 0 0 2px rgba(77, 182, 172, 0.2); }

.modal-dialog-linked-button:focus:hover { background-color: rgba(77, 182, 172, 0.12); }

.modal-dialog-linked-button:active { color: #81c4bf; background-color: rgba(77, 182, 172, 0.25); box-shadow: 0 0 transparent; }

.modal-dialog-linked-button:insensitive { border-color: transparent; color: rgba(207, 216, 220, 0.2436); background-color: transparent; box-shadow: 0 0 transparent; text-shadow: none; icon-shadow: none; }

.modal-dialog-linked-button:first-child { border-radius: 0 0 0 2px; }

.modal-dialog-linked-button:last-child { border-right-width: 0; border-radius: 0 0 2px 0; }

.modal-dialog-linked-button:first-child:last-child { border-right-width: 0; border-radius: 0 0 2px 2px; }

StEntry { border-color: transparent; background-color: rgba(0, 0, 0, 0.01); box-shadow: inset 0 -1px rgba(207, 216, 220, 0.2); min-height: 2.1em; padding: 0 0.6em; border-radius: 0; border-width: 0; color: #CFD8DC; selection-background-color: #00BCD4; selected-color: #FFFFFF; transition-duration: 0s; }

StEntry:hover { border-color: transparent; box-shadow: inset 0 -2px rgba(207, 216, 220, 0.2); }

StEntry:focus { border-color: transparent; box-shadow: inset 0 -2px #00BCD4; }

StEntry:insensitive { border-color: transparent; color: rgba(207, 216, 220, 0.28); box-shadow: inset 0 -1px rgba(207, 216, 220, 0.056); }

StEntry StIcon.capslock-warning { icon-size: 16px; warning-color: #FF9800; padding: 0 0.3em; }

StScrollView.vfade { -st-vfade-offset: 0; }

StScrollView.hfade { -st-hfade-offset: 0; }

StScrollBar { padding: 0; }

StScrollView StScrollBar { min-width: 0.3em; min-height: 0.3em; }

StScrollBar StBin#trough { margin: 0; border-radius: 0; background-color: rgba(207, 216, 220, 0.15); }

StScrollBar StButton#vhandle, StScrollBar StButton#hhandle { margin: 0; border-radius: 0; background-color: rgba(207, 216, 220, 0.297); }

StScrollBar StButton#vhandle:hover, StScrollBar StButton#hhandle:hover { background-color: rgba(207, 216, 220, 0.4785); }

StScrollBar StButton#vhandle:active, StScrollBar StButton#hhandle:active { background-color: #CFD8DC; }

.slider { height: 16px; color: #4DB6AC; -slider-height: 2px; -slider-background-color: rgba(207, 216, 220, 0.2); -slider-border-color: transparent; -slider-active-background-color: #4DB6AC; -slider-active-border-color: transparent; -slider-border-width: 0; -slider-handle-radius: 8px; -barlevel-height: 2px; -barlevel-background-color: rgba(207, 216, 220, 0.2); -barlevel-border-color: transparent; -barlevel-active-background-color: #4DB6AC; -barlevel-active-border-color: transparent; -barlevel-overdrive-color: #FF5252; -barlevel-overdrive-border-color: transparent; -barlevel-overdrive-separator-width: 2px; -barlevel-border-width: 0; }

.check-box StBoxLayout { spacing: 0.8em; }

.check-box StBin { width: 20px; height: 20px; background-image: url("assets/checkbox-off.svg"); color: rgba(207, 216, 220, 0.87); }

.check-box:focus StBin { background-image: url("assets/checkbox-off-hover.svg"); color: #CFD8DC; }

.check-box:checked StBin { background-image: url("assets/checkbox.svg"); color: #CFD8DC; }

.check-box:focus:checked StBin { background-image: url("assets/checkbox-hover.svg"); color: #CFD8DC; }

.toggle-switch { width: 40px; height: 20px; background-size: contain; }

.toggle-switch-us { background-image: url("toggle-off.svg"); }

.toggle-switch-us:checked { background-image: url("toggle-on.svg"); }

.toggle-switch-intl { background-image: url("toggle-off.svg"); }

.toggle-switch-intl:checked { background-image: url("toggle-on.svg"); }

.shell-link { border-radius: 2px; color: #55bcea; }

.shell-link:hover { color: #55bcea; background-color: rgba(85, 188, 234, 0.12); }

.shell-link:active { color: #55bcea; background-color: rgba(85, 188, 234, 0.25); }

.headline { font-size: 11pt; }

.lightbox { background-color: #000000; }

.flashspot { background-color: #FFFFFF; }

.modal-dialog { border: none; border-radius: 2px; color: #CFD8DC; background-color: rgba(34, 45, 50, 0.9); box-shadow: 0 10px 14px rgba(0, 0, 0, 0.44); }

.modal-dialog-content-box { padding: 20px; }

.modal-dialog .run-dialog-entry { width: 20em; margin-bottom: 4px; }

.modal-dialog .run-dialog-error-box { font-size: 9pt; padding-top: 12px; spacing: 4px; color: #F44336; }

.modal-dialog .run-dialog-button-box { padding-top: 0.7em; }

.modal-dialog .run-dialog-label { font-size: 11pt; padding-bottom: 0.3em; font-weight: 400; color: rgba(207, 216, 220, 0.54); }

.mount-dialog-subject, .end-session-dialog-subject { font-size: 13pt; }

.message-dialog-main-layout { padding: 8px 16px 0; spacing: 8px; }

.message-dialog-content { max-width: 28em; spacing: 16px; color: #CFD8DC; }

.message-dialog-icon { min-width: 48px; color: #CFD8DC; icon-size: 48px; -st-icon-style: symbolic; }

.message-dialog-title { font-size: 13pt; color: #CFD8DC; font-weight: 500; }

.message-dialog-subtitle { color: rgba(207, 216, 220, 0.87); font-weight: 400; }

.end-session-dialog { spacing: 30px; border: none; }

.end-session-dialog-list { padding-top: 14px; }

.end-session-dialog-layout:ltr { padding-left: 12px; }

.end-session-dialog-layout:rtl { padding-right: 12px; }

.end-session-dialog-description { width: 28em; padding-bottom: 7px; }

.end-session-dialog-description:ltr { text-align: left; }

.end-session-dialog-description:rtl { text-align: right; }

.end-session-dialog-warning { width: 28em; padding-top: 4px; color: #FF9800; }

.end-session-dialog-warning:ltr { text-align: left; }

.end-session-dialog-warning:rtl { text-align: right; }

.end-session-dialog-logout-icon { width: 48px; height: 48px; border-radius: 2px; background-size: contain; color: #CFD8DC; }

.end-session-dialog-shutdown-icon { width: 48px; height: 48px; color: #CFD8DC; }

.end-session-dialog-inhibitor-layout { spacing: 12px; max-height: 180px; padding-right: 50px; padding-left: 50px; }

.end-session-dialog-session-list, .end-session-dialog-app-list { spacing: 0.7em; }

.end-session-dialog-list-header { font-weight: 700; }

.end-session-dialog-list-header:ltr { text-align: left; }

.end-session-dialog-list-header:rtl { text-align: right; }

.end-session-dialog-app-list-item, .end-session-dialog-session-list-item { spacing: 0.7em; }

.end-session-dialog-app-list-item-name, .end-session-dialog-session-list-item-name { font-weight: 700; }

.end-session-dialog-app-list-item-description { font-size: 10pt; color: rgba(207, 216, 220, 0.54); }

.shell-mount-operation-icon { icon-size: 48px; }

.mount-dialog { spacing: 18px; }

.mount-dialog .message-dialog-title { max-width: 34em; padding-top: 8px; padding-bottom: 5px; }

.mount-dialog .message-dialog-title:ltr { padding-left: 12px; }

.mount-dialog .message-dialog-title:rtl { padding-right: 12px; }

.mount-dialog .message-dialog-body { width: 28em; }

.mount-dialog .message-dialog-body:ltr { padding-left: 12px; }

.mount-dialog .message-dialog-body:rtl { padding-right: 12px; }

.mount-dialog-app-list { max-height: 180px; padding-top: 18px; }

.mount-dialog-app-list:ltr { padding-left: 37px; padding-right: 26px; }

.mount-dialog-app-list:rtl { padding-right: 37px; padding-left: 26px; }

.mount-dialog-app-list-item { color: rgba(207, 216, 220, 0.87); }

.mount-dialog-app-list-item:hover { color: #CFD8DC; }

.mount-dialog-app-list-item:ltr { padding-right: 0.7em; }

.mount-dialog-app-list-item:rtl { padding-left: 0.7em; }

.mount-dialog-app-list-item-icon:ltr { padding-right: 12px; }

.mount-dialog-app-list-item-icon:rtl { padding-left: 12px; }

.mount-dialog-app-list-item-name { font-size: 10pt; }

.prompt-dialog { width: 34em; border: none; }

.prompt-dialog .message-dialog-main-layout { spacing: 18px; padding: 8px; }

.prompt-dialog .message-dialog-content { spacing: 12px; }

.prompt-dialog .message-dialog-title { font-size: 13pt; color: #CFD8DC; font-weight: 500; }

.prompt-dialog-description:ltr { text-align: left; }

.prompt-dialog-description:rtl { text-align: right; }

.prompt-dialog-password-box { spacing: 1em; padding-bottom: 0.7em; }

.prompt-dialog-password-box StEntry { font-family: Noto Sans, Sans-Serif; }

.prompt-dialog-error-label { font-size: 10pt; padding-bottom: 6px; color: #F44336; }

.prompt-dialog-info-label, .prompt-dialog-null-label { font-size: 10pt; padding-bottom: 8px; }

.hidden { color: transparent; }

.polkit-dialog-user-layout { spacing: 7px; }

.polkit-dialog-user-layout:ltr { padding-left: 7px; }

.polkit-dialog-user-layout:rtl { padding-right: 7px; }

.polkit-dialog-user-root-label { color: #FF9800; }

.polkit-dialog-user-icon { width: 48px; height: 48px; border-radius: 2px; background-size: contain; }

.audio-device-selection-dialog { spacing: 2.2em; }

.audio-selection-content { padding: 1.8em; spacing: 1.6em; }

.audio-selection-title { font-weight: 700; text-align: center; }

.audio-selection-box { spacing: 1.6em; }

.audio-selection-device { border: 1px solid rgba(0, 0, 0, 0.13); border-radius: 2px; }

.audio-selection-device:hover, .audio-selection-device:focus { background-color: rgba(207, 216, 220, 0.12); }

.audio-selection-device:active { background-color: #00BCD4; color: #FFFFFF; }

.audio-selection-device-box { padding: 1.6em; spacing: 1.6em; }

.audio-selection-device-icon { icon-size: 64px; }

.access-dialog { spacing: 24px; }

.geolocation-dialog { spacing: 24px; }

.extension-dialog .message-dialog-main-layout { padding: 8px; spacing: 16px; }

.inhibit-shortcuts-dialog { spacing: 24px; }

.network-dialog-secret-table, .keyring-dialog-control-table { spacing-rows: 15px; spacing-columns: 1em; }

.popup-menu { min-width: 15em; }

.popup-menu .popup-sub-menu { border-bottom: 1px solid rgba(0, 0, 0, 0.13); background-color: #243035; box-shadow: inset 0 2px 2px rgba(0, 0, 0, 0.12); }

.popup-menu .popup-sub-menu .popup-menu-item > StLabel:first-child:ltr { margin-left: 16px; padding-left: 14.5px; }

.popup-menu .popup-sub-menu .popup-menu-item > StLabel:first-child:rtl { margin-right: 16px; padding-right: 14.5px; }

.popup-menu .popup-menu-content { padding: 0.21em 0; }

.popup-menu .popup-menu-item { spacing: 6px; color: rgba(207, 216, 220, 0.87); font-weight: 400; transition-duration: 0s; }

.popup-menu .popup-menu-item:ltr { padding: 0.3em 1.2em 0.3em 0; }

.popup-menu .popup-menu-item:rtl { padding: 0.3em 0 0.3em 1.2em; }

.popup-menu .popup-menu-item:checked, .popup-menu .popup-menu-item:checked.selected { background-color: transparent; color: #00BCD4; box-shadow: 0 0 transparent; }

.popup-menu .popup-menu-item:checked:hover { background-color: rgba(0, 188, 212, 0.12); color: #00BCD4; }

.popup-menu .popup-menu-item:checked:active { background-color: rgba(0, 188, 212, 0.25); color: #00BCD4; }

.popup-menu .popup-menu-item:checked:insensitive { color: rgba(0, 188, 212, 0.4); }

.popup-menu .popup-menu-item.selected { background-color: rgba(207, 216, 220, 0.12); color: #CFD8DC; transition-duration: 0s; }

.popup-menu .popup-menu-item:active { background-color: rgba(207, 216, 220, 0.25); color: #CFD8DC; transition-duration: 0.15s; }

.popup-menu .popup-menu-item.selected:active { color: #CFD8DC; }

.popup-menu .popup-menu-item:insensitive { color: rgba(207, 216, 220, 0.28); }

.popup-menu .popup-inactive-menu-item { color: rgba(207, 216, 220, 0.87); }

.popup-menu .popup-inactive-menu-item:insensitive { color: rgba(207, 216, 220, 0.28); }

.popup-menu.panel-menu { -boxpointer-gap: 4px; margin-bottom: 16px; }

.popup-menu StEntry { border-color: transparent; background-color: rgba(0, 0, 0, 0.01); box-shadow: inset 0 -1px rgba(207, 216, 220, 0.2); color: rgba(207, 216, 220, 0.87); transition-duration: 0s; }

.popup-menu StEntry:hover { border-color: transparent; box-shadow: inset 0 -2px rgba(207, 216, 220, 0.2); color: #CFD8DC; }

.popup-menu StEntry:focus { border-color: transparent; box-shadow: inset 0 -2px #00BCD4; color: #CFD8DC; }

.popup-menu StEntry:insensitive { border-color: transparent; color: rgba(207, 216, 220, 0.28); box-shadow: inset 0 -1px rgba(207, 216, 220, 0.056); }

.popup-menu StEntry, .popup-menu StEntry:hover, .popup-menu StEntry:focus, .popup-menu StEntry:insensitive { background-color: rgba(0, 0, 0, 0.01); }

.popup-menu StScrollBar StBin#trough { background-color: rgba(41, 53, 59, 0.55); }

.popup-menu StScrollBar StButton#vhandle, .popup-menu StScrollBar StButton#hhandle { background-color: rgba(207, 216, 220, 0.297); }

.popup-menu StScrollBar StButton#vhandle:hover, .popup-menu StScrollBar StButton#hhandle:hover { background-color: rgba(207, 216, 220, 0.4785); }

.popup-menu StScrollBar StButton#vhandle:active, .popup-menu StScrollBar StButton#hhandle:active { background-color: #CFD8DC; }

.popup-menu-arrow { width: 16px; height: 16px; }

.popup-menu-icon { icon-size: 16px; }

.popup-menu-ornament { font-size: 11pt; width: 1.1em; height: 0; padding-top: 1.3px; color: #00BCD4; text-align: right; font-family: Sans-Serif; font-weight: 700; }

.popup-menu-boxpointer { -arrow-border-radius: 2px; -arrow-background-color: #28343a; -arrow-border-width: 0; -arrow-border-color: transparent; -arrow-base: 48px; -arrow-rise: 0; -arrow-box-shadow: 0 0 transparent; margin: 0.1em 0.3em 0.5em; border-radius: 2px; border-top: 1px solid #2c383e; background-color: #28343a; box-shadow: 0 4.5px 5.5px rgba(0, 0, 0, 0.38); }

.candidate-popup-boxpointer { -arrow-border-radius: 2px; -arrow-background-color: rgba(34, 45, 50, 0.9); -arrow-border-width: 0; -arrow-border-color: transparent; -arrow-base: 48px; -arrow-rise: 0; -arrow-box-shadow: 0 0 transparent; margin: 0.1em 0.3em 0.5em; border-radius: 2px; border-top: 1px solid transparent; background: transparent; background-color: rgba(34, 45, 50, 0.9); color: rgba(207, 216, 220, 0.87); box-shadow: 0 4.5px 5.5px rgba(0, 0, 0, 0.38); }

.popup-separator-menu-item { height: 1px; margin: 0; spacing: 0; border-color: rgba(0, 0, 0, 0.13); border-bottom-width: 1px; border-bottom-style: solid; background-color: transparent; }

.background-menu { -boxpointer-gap: 0; -arrow-rise: 0; }

.system-switch-user-submenu-icon.user-icon { icon-size: 20px; padding: 0 2.25px; }

.system-switch-user-submenu-icon.default-icon { icon-size: 16px; padding: 0 4.25px; }

.osd-window { min-width: 64px; min-height: 64px; margin: 24px; spacing: 0.7em; font-weight: 700; text-align: center; }

.osd-window .osd-monitor-label { font-size: 30pt; }

.osd-window .level { height: 3px; border-radius: 0; background-color: rgba(207, 216, 220, 0.2); color: #00E676; }

.osd-window .level-bar { border-radius: 0; background-color: #00E676; }

.osd-window .level { -barlevel-height: 3px; -barlevel-background-color: transparent; -barlevel-active-background-color: #00E676; -barlevel-overdrive-color: #FF5252; -barlevel-overdrive-separator-width: 3px; -barlevel-border-width: 0; }

.pad-osd-window { padding: 26px; background-color: rgba(34, 45, 50, 0.9); }

.pad-osd-window .pad-osd-title-box { spacing: 10px; }

.pad-osd-window .pad-osd-title-menu-box { spacing: 5px; }

.combo-box-label { width: 15em; }

.switcher-popup { padding: 6px; spacing: 12px; }

.switcher-list > StLabel { min-height: 26.6px; }

.switcher-list-item-container { spacing: 6px; }

.switcher-list .item-box { padding: 6px; border-radius: 2px; }

.switcher-list .item-box:outlined { padding: 4px; border: 2px solid rgba(207, 216, 220, 0.2); }

.switcher-list .item-box:selected { background-color: rgba(77, 182, 172, 0.25); color: #81c4bf; }

.switcher-list .thumbnail-box { padding: 2px; spacing: 4px; }

.switcher-list .thumbnail { width: 192px; }

.switcher-list .separator { width: 1px; background: rgba(0, 0, 0, 0.13); }

.switcher-arrow { border-color: transparent; color: rgba(207, 216, 220, 0.87); }

.switcher-arrow:highlighted { color: #CFD8DC; }

.input-source-switcher-symbol { font-size: 24pt; width: 72px; height: 72px; }

.cycler-highlight { border-radius: 2px 2px 0 0; border: 1px solid #00BCD4; background-color: rgba(0, 188, 212, 0.2); }

.workspace-switcher { padding: 0; spacing: 6px; border: 0; border-radius: 0; background: transparent; }

.workspace-switcher-group { padding: 8px; }

.ws-switcher-active-up { height: 36px; background-color: rgba(77, 182, 172, 0.25); background-image: url("assets/go-up.svg"); background-size: 24px; border-radius: 2px; }

.ws-switcher-active-down { height: 36px; background-color: rgba(77, 182, 172, 0.25); background-image: url("assets/go-down.svg"); background-size: 24px; border-radius: 2px; }

.ws-switcher-box { height: 36px; border: 2px solid rgba(207, 216, 220, 0.2); border-radius: 2px; background: transparent; }

.osd-window, .resize-popup, .switcher-list, .workspace-switcher-container { padding: 12px; border-radius: 2px; border: none; color: #CFD8DC; background-color: rgba(34, 45, 50, 0.9); box-shadow: 0 10px 14px rgba(0, 0, 0, 0.44); }

.tile-preview { border: 1px solid #00BCD4; border-radius: 0; background-color: rgba(0, 188, 212, 0.2); }

.tile-preview-left.on-primary, .tile-preview-left.on-primary.tile-preview-right, .tile-preview-right.on-primary { border-radius: 0; }

#panel { min-height: 25px; height: 1.8em; background-color: rgba(19, 25, 28, 0.54); box-shadow: 0 0 transparent; font-weight: 700; transition-timing-function: cubic-bezier(0, 0, 0.2, 1); transition-duration: 0.4s; }

#panel:overview, #panel.unlock-screen, #panel.login-screen, #panel.lock-screen { background-color: rgba(19, 25, 28, 0.01); box-shadow: 0 0 transparent; transition-timing-function: cubic-bezier(0, 0, 0.2, 1); transition-duration: 0.4s; }

#panel #panelLeft, #panel #panelCenter { spacing: 0; }

#panel .panel-corner { -panel-corner-radius: 0; -panel-corner-background-color: rgba(19, 25, 28, 0.01); -panel-corner-border-width: 0; -panel-corner-border-color: transparent; transition-duration: 0s; }

#panel .panel-corner:hover, #panel .panel-corner:focus { background-color: rgba(19, 25, 28, 0.01); box-shadow: inset 0 2px rgba(207, 216, 220, 0.2); }

#panel .panel-corner:active, #panel .panel-corner:overview { background-color: rgba(19, 25, 28, 0.01); box-shadow: inset 0 2px #00BCD4; }

#panel .panel-corner.lock-screen, #panel .panel-corner.login-screen, #panel .panel-corner.unlock-screen { -panel-corner-radius: 0; -panel-corner-background-color: transparent; -panel-corner-border-width: 0; -panel-corner-border-color: transparent; }

#panel .panel-corner StLabel { padding: 0 2px 1px; }

#panel .panel-corner StIcon { margin-top: 1px; }

#panel .panel-button { -natural-hpadding: 6px; -minimum-hpadding: 6px; color: #CFD8DC; text-shadow: none; icon-shadow: none; font-weight: 700; transition-duration: 0s; }

#panel .panel-button .app-menu-icon { -st-icon-style: symbolic; padding: 0 2px; }

#panel .panel-button:hover { background-color: rgba(19, 25, 28, 0.01); color: #FFFFFF; box-shadow: inset 0 2px rgba(207, 216, 220, 0.2); }

#panel .panel-button:active, #panel .panel-button:focus, #panel .panel-button:checked, #panel .panel-button:overview { background-color: rgba(19, 25, 28, 0.01); color: #FFFFFF; box-shadow: inset 0 2px #00BCD4; }

#panel .panel-button .system-status-icon { icon-size: 16px; padding: 0 3px; }

#panel .panel-button StLabel { padding: 0 2px 1px; }

#panel .panel-button StIcon { margin-top: 1px; }

#panel .panel-button .popup-menu-arrow, #panel .panel-button:hover .popup-menu-arrow, #panel .panel-button:active .popup-menu-arrow, #panel .panel-button:focus .popup-menu-arrow, #panel .panel-button:checked .popup-menu-arrow, #panel .panel-button:overview .popup-menu-arrow, #panel .panel-button.unlock-screen .popup-menu-arrow, #panel .panel-button.login-screen .popup-menu-arrow, #panel .panel-button.lock-screen .popup-menu-arrow { width: 0; height: 0; color: transparent; icon-shadow: none; }

#panel .panel-button.clock-display > StBoxLayout > StIcon { padding-bottom: 4.5px; icon-size: 16px; color: #009688; }

#panel .panel-button.clock-display:hover > StBoxLayout > StIcon, #panel .panel-button.clock-display:active > StBoxLayout > StIcon { color: #4DB6AC; }

#panel StLabel { text-shadow: none; }

#panel StIcon { icon-shadow: none; }

#panel .panel-status-indicators-box, #panel .panel-status-menu-box { spacing: 0; }

#panel .screencast-indicator { color: #FF5252; }

#panel .remote-access-indicator { color: #FF9800; }

#panel.solid { background-color: #13191c; background-gradient-start: #13191c; background-gradient-end: #13191c; transition-timing-function: cubic-bezier(0, 0, 0.2, 1); transition-duration: 0.4s; }

#panel.solid .panel-corner { -panel-corner-background-color: #13191c; }

#panel.solid .panel-button { color: #CFD8DC; }

#panel.solid .panel-button:hover, #panel.solid .panel-button:active, #panel.solid .panel-button:focus, #panel.solid .panel-button:checked { color: #FFFFFF; }

#panel.solid .panel-button > .system-status-icon, #panel.solid .panel-button:hover > .system-status-icon, #panel.solid .panel-button:active > .system-status-icon, #panel.solid .panel-button:focus > .system-status-icon, #panel.solid .panel-button:checked > .system-status-icon, #panel.solid .panel-button:overview > .system-status-icon, #panel.solid .panel-button.unlock-screen > .system-status-icon, #panel.solid .panel-button.login-screen > .system-status-icon, #panel.solid .panel-button.lock-screen > .system-status-icon { icon-shadow: none; }

#calendarArea { padding: 0.5em 0.7em; }

.calendar { margin-bottom: 0.7em; }

.calendar, .datemenu-today-button, .datemenu-displays-box, .message-list-sections { margin: 0 1em; }

.datemenu-calendar-column { spacing: 0.5em; }

.datemenu-displays-section { padding-bottom: 0; }

.datemenu-displays-box { spacing: 0.7em; }

.datemenu-calendar-column { border-style: solid; border-color: rgba(0, 0, 0, 0.13); }

.datemenu-calendar-column:ltr { border-left-width: 1px; }

.datemenu-calendar-column:rtl { border-right-width: 1px; }

.datemenu-today-button, .world-clocks-button, .weather-button, .events-section-title { padding: 0.4em; border-radius: 2px; }

.datemenu-today-button, .world-clocks-button, .weather-button, .events-section-title { color: rgba(207, 216, 220, 0.87); }

.datemenu-today-button:hover, .datemenu-today-button:focus, .world-clocks-button:hover, .world-clocks-button:focus, .weather-button:hover, .weather-button:focus, .events-section-title:hover, .events-section-title:focus { color: #CFD8DC; background-color: rgba(207, 216, 220, 0.12); }

.datemenu-today-button:active, .world-clocks-button:active, .weather-button:active, .events-section-title:active { color: #CFD8DC; background-color: rgba(207, 216, 220, 0.25); }

.datemenu-today-button .day-label { color: rgba(207, 216, 220, 0.54); font-weight: 700; }

.datemenu-today-button .date-label { font-size: 15pt; color: rgba(207, 216, 220, 0.87); }

.datemenu-today-button:hover .day-label, .datemenu-today-button:focus .day-label, .datemenu-today-button:active .day-label { color: rgba(207, 216, 220, 0.87); }

.datemenu-today-button:hover .date-label, .datemenu-today-button:focus .date-label, .datemenu-today-button:active .date-label { color: #CFD8DC; }

.world-clocks-header, .weather-header, .events-section-title { color: rgba(207, 216, 220, 0.54); font-weight: 700; }

.world-clocks-grid { spacing-rows: 0.4em; }

.weather-box { spacing: 0.4em; }

.calendar-month-label { padding: 4px 0; color: #CFD8DC; font-weight: 700; }

.pager-button { width: 2.1em; height: 2.1em; border-radius: 100px; color: #CFD8DC; background-color: transparent; }

.pager-button:hover, .pager-button:focus { background-color: rgba(207, 216, 220, 0.12); }

.pager-button:active { background-color: rgba(207, 216, 220, 0.25); }

.calendar-change-month-back { background-image: url("assets/calendar-arrow-left.svg"); }

.calendar-change-month-back:hover, .calendar-change-month-back:focus { background-image: url("assets/calendar-arrow-left-hover.svg"); }

.calendar-change-month-back:rtl { background-image: url("assets/calendar-arrow-right.svg"); }

.calendar-change-month-back:rtl:hover, .calendar-change-month-back:rtl:focus { background-image: url("assets/calendar-arrow-right-hover.svg"); }

.calendar-change-month-forward { background-image: url("assets/calendar-arrow-right.svg"); }

.calendar-change-month-forward:hover, .calendar-change-month-forward:focus { background-image: url("assets/calendar-arrow-right-hover.svg"); }

.calendar-change-month-forward:rtl { background-image: url("assets/calendar-arrow-left.svg"); }

.calendar-change-month-forward:rtl:hover, .calendar-change-month-forward:rtl:focus { background-image: url("assets/calendar-arrow-left-hover.svg"); }

.calendar-day-base { font-size: 9pt; width: 2.4em; height: 2.4em; padding: 0; margin: 0.2em; border-radius: 100px; text-align: center; transition-duration: 0.1s; }

.calendar-day-base:hover, .calendar-day-base:focus { background-color: rgba(207, 216, 220, 0.12); }

.calendar-day-base:active, .calendar-day-base:active:hover, .calendar-day-base:selected, .calendar-day-base:selected:hover { color: #FFFFFF; background-color: #00BCD4; transition-duration: 0.15s; }

.calendar-day-base.calendar-day-heading { font-size: 9pt; width: 2.4em; height: 1.9em; margin-top: 0.2em; padding: 0.5em 0 0; background-color: transparent; color: rgba(207, 216, 220, 0.54); font-weight: 500; text-align: center; }

.calendar-week-number { width: 2.4em; height: 1.9em; margin: 0.2em; padding: 0.5em 0 0; background-color: transparent; color: rgba(207, 216, 220, 0.54); font-weight: 700; text-align: center; }

.calendar-day { border-width: 0; color: #CFD8DC; }

.calendar-day-top { border-top-width: 0; }

.calendar-day-left { border-left-width: 0; }

.calendar-day-with-events { background-image: none; color: #55bcea; font-weight: 500; text-decoration: underline; }

.calendar-day-with-events:hover { background-color: rgba(85, 188, 234, 0.12); }

.calendar-day-with-events:active, .calendar-day-with-events:active:hover, .calendar-day-with-events:selected, .calendar-day-with-events:selected:hover { color: #FFFFFF; background-color: #00BCD4; border-color: transparent; }

.calendar-today { border: none; font-weight: 700; }

.calendar-today, .calendar-today.calendar-day-with-events { background-color: rgba(19, 25, 28, 0.87); color: rgba(255, 255, 255, 0.87); }

.calendar-today:hover, .calendar-today:focus, .calendar-today.calendar-day-with-events:hover, .calendar-today.calendar-day-with-events:focus { background-color: #13191c; color: #FFFFFF; }

.calendar-today:selected, .calendar-today:selected:hover, .calendar-today.calendar-day-with-events:selected, .calendar-today.calendar-day-with-events:selected:hover { color: #FFFFFF; background-color: #00BCD4; border-color: transparent; }

.calendar-other-month-day { color: rgba(207, 216, 220, 0.297); }

.calendar-other-month-day:hover, .calendar-other-month-day:focus { color: rgba(207, 216, 220, 0.54); background-color: rgba(207, 216, 220, 0.0648); }

.calendar-other-month-day.calendar-day-with-events { color: rgba(85, 188, 234, 0.297); }

.calendar-other-month-day.calendar-day-with-events:hover, .calendar-other-month-day.calendar-day-with-events:focus { color: rgba(85, 188, 234, 0.54); background-color: rgba(85, 188, 234, 0.0648); }

.message-list { width: 380px; }

.message-list-clear-button.button { margin: 1.2em 1.2em 0; color: rgba(129, 196, 191, 0.87); background-color: transparent; font-weight: 500; }

.message-list-clear-button.button:hover, .message-list-clear-button.button:focus { color: #81c4bf; background-color: rgba(77, 182, 172, 0.12); }

.message-list-clear-button.button:active { color: #81c4bf; background-color: rgba(77, 182, 172, 0.25); box-shadow: 0 0 transparent; }

.message-list-clear-button.button:insensitive { border-color: transparent; color: rgba(207, 216, 220, 0.2436); background-color: transparent; box-shadow: 0 0 transparent; text-shadow: none; icon-shadow: none; }

.message-list-sections { spacing: 0; }

.message-list-section { spacing: 0; padding: 0; }

.message-list-section-list { spacing: 1px; margin-bottom: 0.4em; padding: 0; border: 1px solid rgba(0, 0, 0, 0.01); border-radius: 2px; background-color: rgba(0, 0, 0, 0.13); }

.message-list-placeholder { color: rgba(207, 216, 220, 0.54); }

.message { padding: 0.6em; border-radius: 0; background-color: transparent; color: #CFD8DC; }

.popup-menu .message { padding: 0.45em; background-color: #29353b; color: rgba(207, 216, 220, 0.87); }

.popup-menu .message .message-icon-bin > StIcon, .popup-menu .message .message-title, .popup-menu .message .message-content { color: rgba(207, 216, 220, 0.87); }

.popup-menu .message:hover, .popup-menu .message:focus { background-color: #3f4a50; color: #CFD8DC; }

.popup-menu .message:hover .message-icon-bin > StIcon, .popup-menu .message:hover .message-title, .popup-menu .message:hover .message-content, .popup-menu .message:focus .message-icon-bin > StIcon, .popup-menu .message:focus .message-title, .popup-menu .message:focus .message-content { color: #CFD8DC; }

.popup-menu .message:hover .message-secondary-bin, .popup-menu .message:hover .message-secondary-bin > .event-time, .popup-menu .message:focus .message-secondary-bin, .popup-menu .message:focus .message-secondary-bin > .event-time { color: rgba(207, 216, 220, 0.87); }

.popup-menu .message:active { background-color: #535e63; color: #CFD8DC; }

.popup-menu .message:active .message-icon-bin > StIcon, .popup-menu .message:active .message-title, .popup-menu .message:active .message-content { color: #CFD8DC; }

.popup-menu .message:active .message-secondary-bin, .popup-menu .message:active .message-secondary-bin > .event-time { color: rgba(207, 216, 220, 0.87); }

.message-icon-bin { margin: 0.2em 0.45em 0; padding: 0; }

.message-icon-bin > StIcon { min-width: 16px; min-height: 16px; color: #CFD8DC; icon-size: 16px; -st-icon-style: symbolic; }

.message-secondary-bin { color: rgba(207, 216, 220, 0.54); }

.message-secondary-bin:ltr { padding-left: 0.45em; }

.message-secondary-bin:rtl { padding-right: 0.45em; }

.message-secondary-bin > .event-time { font-size: 9pt; min-height: 12px; margin-bottom: 0.305em; padding: 0; color: rgba(207, 216, 220, 0.54); }

.message-secondary-bin > StIcon { icon-size: 16px; }

.popup-menu .message-secondary-bin, .popup-menu .message-secondary-bin > .event-time { color: rgba(207, 216, 220, 0.54); }

.message-title { font-size: 11pt; min-height: 14px; margin-bottom: 0.05em; padding: 0; color: #CFD8DC; font-weight: 700; }

.message-content { padding: 0; color: #CFD8DC; }

.message-content * > StIcon { padding: 0.2em; border-radius: 100px; icon-size: 16px; color: rgba(129, 196, 191, 0.87); }

.message-content *:hover > StIcon, .message-content *:focus > StIcon { color: #81c4bf; background-color: rgba(77, 182, 172, 0.12); }

.message-content *:active > StIcon { color: #81c4bf; background-color: rgba(77, 182, 172, 0.25); }

.message-media-control { padding: 0 8px; margin: 0 6px; border-radius: 100px; color: rgba(129, 196, 191, 0.87); background: transparent; background-size: 32px 32px; }

.message-media-control:hover { color: #81c4bf; background-image: url("assets/media-control-hover.svg"); background-size: 32px 32px; }

.message-media-control:active { color: #81c4bf; background-image: url("assets/media-control-active.svg"); background-size: 32px 32px; }

.message-media-control:insensitive { color: rgba(129, 196, 191, 0.28); background-image: none; background: transparent; }

.media-message-cover-icon { icon-size: 36px !important; }

.media-message-cover-icon.fallback { icon-size: 16px !important; padding: 10px; border: none; border-radius: 2px; color: rgba(207, 216, 220, 0.54); background-color: rgba(207, 216, 220, 0.12); box-shadow: 0 0 transparent; }

.popup-menu .message .media-message-cover-icon.fallback { color: rgba(207, 216, 220, 0.54); background-color: rgba(207, 216, 220, 0.12); }

.popup-menu .message:hover .media-message-cover-icon.fallback, .popup-menu .message:focus .media-message-cover-icon.fallback, .popup-menu .message:active .media-message-cover-icon.fallback { color: rgba(207, 216, 220, 0.87); background-color: rgba(77, 182, 172, 0.25); }

#appMenu { spinner-image: url("process-working.svg"); padding: 0 6px; }

#appMenu StLabel:ltr { padding: 0 6px 0 2px; }

#appMenu StLabel:rtl { padding: 0 2px 0 6px; }

#appMenu .label-shadow { color: transparent; }

.aggregate-menu { min-width: 24em; }

.aggregate-menu .popup-menu-icon { padding: 0 4px; }

.system-menu-action { padding: 10px; border-radius: 100px; border: none; color: rgba(129, 196, 191, 0.87); -st-icon-style: symbolic; }

.system-menu-action:hover, .system-menu-action:focus { padding: 10px; border: none; background-color: rgba(77, 182, 172, 0.12); color: #81c4bf; }

.system-menu-action:active { color: #81c4bf; background-color: rgba(77, 182, 172, 0.25); }

.system-menu-action > StIcon { icon-size: 16px; }

.ripple-box { width: 52px; height: 52px; background-image: url("assets/corner-ripple-ltr.svg"); background-size: contain; }

.ripple-box:rtl { background-image: url("assets/corner-ripple-rtl.svg"); }

.window-close { height: 32px; width: 32px; -shell-close-overlap: 24px; -st-background-image-shadow: 0 1px 2px rgba(0, 0, 0, 0.28); background-image: url("assets/window-close.svg"); background-size: 32px; }

.window-close:hover { background-image: url("assets/window-close-hover.svg"); -st-background-image-shadow: 0 2.5px 4.5px rgba(0, 0, 0, 0.34); }

.window-close:active { background-image: url("assets/window-close-active.svg"); }

.nm-dialog { max-height: 34em; min-height: 28em; min-width: 34em; }

.nm-dialog-content { spacing: 16px; padding: 18px; }

.nm-dialog-header-hbox { spacing: 7px; color: rgba(207, 216, 220, 0.54); }

.nm-dialog-header { font-size: 11pt; color: #CFD8DC; font-weight: 700; }

.nm-dialog-header-icon { icon-size: 32px; color: #CFD8DC; }

.nm-dialog-airplane-box { spacing: 9px; }

.nm-dialog-airplane-box .button { color: rgba(129, 196, 191, 0.87); background-color: transparent; font-weight: 500; }

.nm-dialog-airplane-box .button:hover { color: #81c4bf; background-color: rgba(77, 182, 172, 0.12); }

.nm-dialog-airplane-box .button:active { color: #81c4bf; background-color: rgba(77, 182, 172, 0.25); box-shadow: 0 0 transparent; }

.nm-dialog-airplane-box .button:insensitive { border-color: transparent; color: rgba(207, 216, 220, 0.2436); background-color: transparent; box-shadow: 0 0 transparent; text-shadow: none; icon-shadow: none; }

.nm-dialog-airplane-headline { font-weight: 700; text-align: center; }

.nm-dialog-airplane-text { color: #CFD8DC; }

.nm-dialog-scroll-view { border: 1px solid rgba(0, 0, 0, 0.13); }

.nm-dialog-item { font-size: 10pt; spacing: 16px; padding: 8px; color: #CFD8DC; }

.nm-dialog-item:selected { background-color: #00BCD4; color: #FFFFFF; }

.nm-dialog-icons { spacing: 6px; }

.nm-dialog-icon { icon-size: 16px; }

.no-networks-label { color: rgba(207, 216, 220, 0.54); }

.no-networks-box { spacing: 8px; }

#overview { spacing: 18px; }

#overview-controls { padding-bottom: 26px; }

.window-picker { -horizontal-spacing: 12px; -vertical-spacing: 12px; padding: 0 12px 12px; }

.window-picker.external-monitor { padding: 12px; }

.window-clone-border { border: 4px solid rgba(207, 216, 220, 0.12); border-radius: 2px 2px 0 0; box-shadow: inset 0 0 0 1px rgba(207, 216, 220, 0.12); }

.window-caption { max-width: 75em; padding: 0.4em 0.9em 0.5em; border-radius: 100px; border-top: 1px solid rgba(255, 255, 255, 0.07); color: #CFD8DC; background-color: #13191c; box-shadow: 0 4.5px 5.5px rgba(0, 0, 0, 0.38); text-align: center; }

.search-entry { width: 340px; padding: 0.3em 0.6em; border-radius: 100px; border-top: 1px solid transparent; color: rgba(207, 216, 220, 0.54); background-color: rgba(19, 25, 28, 0.54); box-shadow: 0 0 transparent; font-weight: 400; transition-duration: 0.15s; selection-background-color: #00BCD4; selected-color: #FFFFFF; }

.search-entry StLabel { margin-bottom: 0.1em; }

.search-entry:hover, .search-entry:focus { border-top: 1px solid rgba(255, 255, 255, 0.0378); color: #CFD8DC; background-color: #13191c; box-shadow: 0 2.5px 4.5px rgba(0, 0, 0, 0.34); }

.search-entry .search-entry-icon { icon-size: 16px; color: rgba(207, 216, 220, 0.54); }

.search-entry:hover .search-entry-icon, .search-entry:focus .search-entry-icon { color: #CFD8DC; }

#searchResultsBin { max-width: 1000px; }

#searchResultsContent { spacing: 4px; padding: 4px; }

.search-section { spacing: 4px; }

.search-section-content { spacing: 4px; }

.search-section-separator { height: 1px; background-color: rgba(207, 216, 220, 0.2); }

.search-section-separator:ltr { margin-left: 168px; }

.search-section-separator:rtl { margin-right: 168px; }

.list-search-results { spacing: 3px; }

.list-search-result { padding: 0; border-radius: 2px; transition-duration: 0s; }

.list-search-result:ltr { margin-right: 12px; }

.list-search-result:rtl { margin-left: 12px; }

.list-search-result:focus, .list-search-result:selected, .list-search-result:hover { background-color: rgba(207, 216, 220, 0.12); transition-duration: 0s; }

.list-search-result:focus .list-search-result-title, .list-search-result:selected .list-search-result-title, .list-search-result:hover .list-search-result-title { color: #FFFFFF; }

.list-search-result:focus .list-search-result-description, .list-search-result:selected .list-search-result-description, .list-search-result:hover .list-search-result-description { color: #CFD8DC; }

.list-search-result:active { background-color: rgba(207, 216, 220, 0.25); transition-duration: 0.15s; }

.list-search-result:active .list-search-result-title { color: #FFFFFF; }

.list-search-result:active .list-search-result-description { color: #CFD8DC; }

.list-search-result:checked { background-color: #00BCD4; transition-duration: 0.15s; }

.list-search-result:checked .list-search-result-title { color: #CFD8DC; }

.list-search-result:checked .list-search-result-description { color: rgba(207, 216, 220, 0.87); }

.list-search-result-content { spacing: 4px; padding: 4px; min-height: 48px; }

.list-search-result-title { font-size: 11pt; color: #CFD8DC; font-weight: 700; }

.list-search-result-title StIcon:ltr, .list-search-result-title StLabel:ltr { padding-left: 4px; }

.list-search-result-title StIcon:rtl, .list-search-result-title StLabel:rtl { padding-right: 4px; }

.list-search-result-description { padding: 0; color: rgba(207, 216, 220, 0.87); }

.list-search-provider-content { spacing: 4px; padding: 4px; }

.list-search-provider-details { font-size: 9pt; width: 120px; color: rgba(207, 216, 220, 0.87); }

.search-provider-icon:hover .list-search-provider-details, .search-provider-icon:active .list-search-provider-details { color: #CFD8DC; }

.search-provider-icon:checked .list-search-provider-details { color: #FFFFFF; }

.search-provider-icon { min-height: 58.08px; padding: 0 3px; border: none; border-radius: 2px; transition-duration: 0s; }

.search-provider-icon:focus, .search-provider-icon:selected, .search-provider-icon:hover { background-color: rgba(207, 216, 220, 0.12); transition-duration: 0s; }

.search-provider-icon:active { background-color: rgba(207, 216, 220, 0.25); transition-duration: 0.15s; }

.search-provider-icon:checked { background-color: #00BCD4; transition-duration: 0.15s; }

#dash { font-size: 9pt; padding: 1px 0; border: none; color: #CFD8DC; background-color: rgba(207, 216, 220, 0.12); box-shadow: 0 0 transparent; transition-duration: 0.4s; }

#dash:ltr { border-radius: 0 2px 2px 0; }

#dash:rtl { border-radius: 2px 0 0 2px; }

#dash .placeholder { height: 24px; background-image: url("assets/dash-placeholder.svg"); background-size: contain; }

#dash .empty-dash-drop-target { width: 24px; height: 24px; }

.dash-item-container { background: transparent; }

.dash-item-container > StWidget { padding: 0; }

.dash-label { padding: 6px 7px 7px; border-radius: 2px; color: #CFD8DC; background-color: rgba(34, 45, 50, 0.9); box-shadow: 0 2.5px 4.5px rgba(0, 0, 0, 0.34); text-align: center; -x-offset: 8px; }

.icon-grid { spacing: 30px; -shell-grid-horizontal-item-size: 136px; -shell-grid-vertical-item-size: 136px; }

.icon-grid .overview-icon { icon-size: 96px; }

.system-action-icon { icon-size: 48px; border-radius: 100px; background-color: rgba(34, 45, 50, 0.9); color: #81c4bf; box-shadow: 0 2.5px 4.5px rgba(0, 0, 0, 0.34); }

.app-view-controls { width: 340px; padding-bottom: 18px; background-color: rgba(0, 0, 0, 0.01) !important; box-shadow: inset 0 1px rgba(207, 216, 220, 0.2); }

.app-view-control { padding: 5px 32px 6px; border-radius: 0; font-weight: 500; color: rgba(207, 216, 220, 0.87); background-color: rgba(0, 0, 0, 0.01) !important; }

.app-view-control:hover { color: #CFD8DC; background-color: rgba(207, 216, 220, 0.12) !important; box-shadow: inset 0 2px rgba(207, 216, 220, 0.2); }

.app-view-control:active { color: #CFD8DC; background-color: rgba(207, 216, 220, 0.25) !important; box-shadow: inset 0 2px #00BCD4; }

.app-view-control:checked { color: #CFD8DC; background-color: rgba(0, 0, 0, 0.01) !important; box-shadow: inset 0 2px #00BCD4; }

.app-view-control:hover:checked { color: #CFD8DC; background-color: rgba(207, 216, 220, 0.12) !important; box-shadow: inset 0 2px #00BCD4; }

.app-well-app .overview-icon, .app-well-app.app-folder .overview-icon, .show-apps .overview-icon, .grid-search-result .overview-icon { padding: 9px; border: none; border-radius: 2px; color: #CFD8DC; text-align: center; transition-duration: 0s; }

.app-well-app .overview-icon StLabel, .app-well-app.app-folder .overview-icon StLabel, .show-apps .overview-icon StLabel, .grid-search-result .overview-icon StLabel { padding-top: 6px; }

.app-well-app:focus .overview-icon, .app-well-app:hover .overview-icon, .app-well-app:selected .overview-icon, .app-well-app.app-folder:focus .overview-icon, .app-well-app.app-folder:hover .overview-icon, .app-well-app.app-folder:selected .overview-icon, .show-apps:focus .overview-icon, .show-apps:hover .overview-icon, .show-apps:selected .overview-icon, .grid-search-result:focus .overview-icon, .grid-search-result:hover .overview-icon, .grid-search-result:selected .overview-icon { border-image: none; background-color: rgba(207, 216, 220, 0.12); background-image: none; color: #FFFFFF; transition-duration: 0.1s; }

.app-well-app:active .overview-icon, .app-well-app.app-folder:active .overview-icon, .show-apps:active .overview-icon, .grid-search-result:active .overview-icon { border-image: none; background-color: rgba(207, 216, 220, 0.25); background-image: none; color: #FFFFFF; transition-duration: 0.15s; }

.app-well-app:checked .overview-icon, .app-well-app.app-folder:checked .overview-icon, .show-apps:checked .overview-icon, .grid-search-result:checked .overview-icon { border-radius: 0; background-color: rgba(0, 0, 0, 0.01); color: #FFFFFF; box-shadow: inset 0 -2px #00BCD4; transition-duration: 0s; }

#dash .app-well-app .overview-icon, #dash .show-apps .overview-icon { border-radius: 100px; transition-duration: 0s; }

#dash .app-well-app:hover .overview-icon, #dash .app-well-app:focus .overview-icon, #dash .show-apps:hover .overview-icon, #dash .show-apps:focus .overview-icon { background-color: rgba(207, 216, 220, 0.12); transition-duration: 0.1s; }

#dash .app-well-app:active .overview-icon, #dash .show-apps:active .overview-icon { background-color: rgba(207, 216, 220, 0.25); transition-duration: 0.15s; }

#dash .app-well-app:checked .overview-icon, #dash .app-well-app:checked:hover .overview-icon, #dash .show-apps:checked .overview-icon, #dash .show-apps:checked:hover .overview-icon { background-color: rgba(0, 188, 212, 0.12); color: #00BCD4; box-shadow: 0 0 transparent; transition-duration: 0s; }

.app-well-app-running-dot { width: 32px; height: 2px; margin-bottom: 0; background-color: #00BCD4; }

.show-apps .show-apps-icon { border: none; }

.show-apps:checked .show-apps-icon, .show-apps:checked:hover .show-apps-icon { color: #00BCD4; }

.app-well-app.app-folder > .overview-icon { background-color: rgba(207, 216, 220, 0.12); box-shadow: 0 0 transparent; }

.app-well-app.app-folder:hover > .overview-icon, .app-well-app.app-folder:focus > .overview-icon { background-color: rgba(207, 216, 220, 0.25); box-shadow: 0 0 transparent; }

.app-well-app.app-folder:active > .overview-icon, .app-well-app.app-folder:active:hover > .overview-icon { border-radius: 0; background-color: rgba(207, 216, 220, 0.25); box-shadow: inset 0 -2px #00BCD4; }

.app-well-app.app-folder:checked > .overview-icon, .app-well-app.app-folder:checked:hover > .overview-icon { border-radius: 0; background-color: rgba(0, 0, 0, 0.01); box-shadow: inset 0 -2px #00BCD4; }

.app-folder-popup { -arrow-border-radius: 0; -arrow-background-color: transparent; -arrow-base: 0; -arrow-rise: 12px; }

.app-folder-popup-bin { padding: 5px; border-radius: 2px; border-top: 0 none transparent; background-color: rgba(34, 45, 50, 0.9); box-shadow: 0 1px 2px rgba(0, 0, 0, 0.28); }

.app-folder-icon { padding: 5px; spacing-rows: 5px; spacing-columns: 5px; }

.page-indicator { padding: 14px 20px; }

.page-indicator .page-indicator-icon { width: 12px; height: 12px; margin: 2px; padding: 0; border-radius: 12px; background-image: none; background-color: rgba(207, 216, 220, 0.2); }

.page-indicator:hover .page-indicator-icon { margin: 0; padding: 2px; background-image: none; background-color: rgba(207, 216, 220, 0.25); }

.page-indicator:active .page-indicator-icon { margin: 2px; padding: 0; background-image: none; background-color: rgba(0, 188, 212, 0.87); }

.page-indicator:checked .page-indicator-icon { margin: 0; padding: 2px; background-image: none; background-color: #00BCD4; }

.app-well-app > .overview-icon.overview-icon-with-label, .grid-search-result .overview-icon.overview-icon-with-label { padding: 10px 8px 5px 8px; spacing: 4px; }

.workspace-thumbnails, .workspace-thumbnails-left { visible-width: 32px; spacing: 12px; margin-bottom: 32px; padding: 12px; border: none; border-radius: 0; background-color: rgba(19, 25, 28, 0.01); color: #CFD8DC; }

.workspace-thumbnails StBin.placeholder, .workspace-thumbnails-left StBin.placeholder { height: 4px; background-color: #4DB6AC; }

.workspace-thumbnail-indicator { border: 0 solid #00BCD4; border-radius: 0; }

.workspace-thumbnail-indicator:ltr { padding: 6px 6px 6px 10px; border-left-width: 2px; }

.workspace-thumbnail-indicator:rtl { padding: 6px 10px 6px 6px; border-right-width: 2px; }

.workspace-thumbnails, .workspace-thumbnails-left:rtl { box-shadow: inset 1px 0 rgba(207, 216, 220, 0.2); }

.workspace-thumbnails:rtl, .workspace-thumbnails-left { box-shadow: inset -1px 0 rgba(207, 216, 220, 0.2); }

.workspace-thumbnails:rtl .workspace-thumbnail-indicator, .workspace-thumbnails-left .workspace-thumbnail-indicator { padding: 6px 10px 6px 6px; border-right-width: 2px; }

.search-display > StBoxLayout, .all-apps, .frequent-apps > StBoxLayout { padding: 0 88px 10px 88px; }

.search-statustext, .no-frequent-applications-label { font-size: 20pt; font-weight: 700; color: rgba(207, 216, 220, 0.54); }

.url-highlighter { link-color: #55bcea; }

.notification-banner { font-size: 11pt; width: 34em; margin: 6px; border: none; border-radius: 2px; background-color: rgba(34, 45, 50, 0.9); color: #CFD8DC; box-shadow: 0 2.5px 4.5px rgba(0, 0, 0, 0.34); }

.notification-banner:hover, .notification-banner:focus { background-color: rgba(34, 45, 50, 0.9); color: #CFD8DC; box-shadow: 0 2.5px 4.5px rgba(0, 0, 0, 0.34); }

.notification-banner .notification-icon { padding: 6px; }

.notification-banner .notification-content { padding: 6px; spacing: 6px; }

.notification-banner .notification-actions { padding: 0; spacing: 0; border: transparent; background-color: transparent; }

.notification-banner .secondary-icon { icon-size: 16px; }

.notification-banner * > StIcon { color: rgba(129, 196, 191, 0.87); }

.notification-banner *:hover > StIcon, .notification-banner *:focus > StIcon { color: #81c4bf; background-color: rgba(77, 182, 172, 0.12); }

.notification-banner *:active > StIcon { color: #81c4bf; background-color: rgba(77, 182, 172, 0.25); }

.notification-banner .notification-button { padding: 6px 3px 7px; background-color: transparent; color: rgba(129, 196, 191, 0.87); font-weight: 500; }

.notification-banner .notification-button:first-child { border-radius: 0 0 0 2px; }

.notification-banner .notification-button:last-child { border-radius: 0 0 2px 0; }

.notification-banner .notification-button:hover { color: #81c4bf; background-color: rgba(77, 182, 172, 0.12); }

.notification-banner .notification-button:focus { color: #81c4bf; }

.notification-banner .notification-button:active { color: #81c4bf; background-color: rgba(77, 182, 172, 0.25); }

.summary-source-counter { font-size: 10pt; width: 1.6em; height: 1.6em; border-radius: 0.9em; border: 2px solid #CFD8DC; font-weight: 700; -shell-counter-overlap-x: 3px; -shell-counter-overlap-y: 3px; background-color: #00BCD4; color: #FFFFFF; box-shadow: 0 2.5px 4.5px rgba(0, 0, 0, 0.34); }

.secondary-icon { icon-size: 14px; }

.chat-body { spacing: 5px; }

.chat-response { margin: 5px; }

.chat-log-message { color: rgba(207, 216, 220, 0.87); }

.chat-new-group { padding-top: 1em; }

.chat-received:ltr { padding-left: 4px; }

.chat-received:rtl { padding-right: 4px; }

.chat-sent { color: rgba(207, 216, 220, 0.87); }

.chat-sent:ltr { padding-left: 18pt; }

.chat-sent:rtl { padding-right: 18pt; }

.chat-meta-message { font-size: 9pt; font-weight: 700; color: rgba(207, 216, 220, 0.28); }

.chat-meta-message:ltr { padding-left: 4px; }

.chat-meta-message:rtl { padding-right: 4px; }

.hotplug-transient-box { spacing: 6px; padding: 2px 72px 2px 12px; }

.hotplug-notification-item { padding: 2px 10px; color: rgba(129, 196, 191, 0.87); font-weight: 700; }

.hotplug-notification-item:hover { color: #81c4bf; background-color: rgba(77, 182, 172, 0.12); }

.hotplug-notification-item:active { color: #81c4bf; background-color: rgba(77, 182, 172, 0.25); }

.hotplug-notification-item:focus { color: #81c4bf; }

.hotplug-notification-item:insensitive { border-color: transparent; color: rgba(207, 216, 220, 0.2436); background-color: transparent; box-shadow: 0 0 transparent; text-shadow: none; icon-shadow: none; }

.hotplug-notification-item-icon { padding: 2px 5px; icon-size: 24px; }

.hotplug-resident-box { spacing: 8px; }

.hotplug-resident-mount { spacing: 8px; border-radius: 2px; }

.hotplug-resident-mount:hover { background-color: rgba(207, 216, 220, 0.12); }

.hotplug-resident-mount:active { background-color: rgba(207, 216, 220, 0.25); }

.hotplug-resident-mount-label { padding-left: 6px; color: rgba(207, 216, 220, 0.87); }

.hotplug-resident-mount-icon { padding-left: 6px; icon-size: 24px; }

.hotplug-resident-eject-icon { icon-size: 16px; }

.hotplug-resident-eject-button { padding: 7px; border-radius: 2px; color: #CFD8DC; }

.magnifier-zoom-region { border: 2px solid #00BCD4; }

.magnifier-zoom-region.full-screen { border-width: 0; }

#keyboard { background-color: rgba(19, 25, 28, 0.54); }

.key-container { padding: 3.999; spacing: 3.999; }

.keyboard-layout { spacing: 3.999; padding: 3.999; }

.keyboard-row { spacing: 3.999; }

.keyboard-key { min-height: 26.66; min-width: 26.66; padding: 0; border-radius: 2px; border: none; background-color: #222d32; color: rgba(207, 216, 220, 0.87); box-shadow: 0 0 transparent; text-shadow: none; icon-shadow: none; font-size: 26.66; font-weight: 700; transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1); }

.keyboard-key:focus, .keyboard-key:hover, .keyboard-key:checked { background-color: #374246; color: #CFD8DC; transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1); }

.keyboard-key:active { background-color: #4d585d; color: #CFD8DC; transition-timing-function: cubic-bezier(0, 0, 0.2, 1); }

.keyboard-key:grayed { background-color: #13191c; color: rgba(207, 216, 220, 0.54); transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1); }

.keyboard-key.default-key { background-color: #1e282d; background-size: 26.66; color: rgba(207, 216, 220, 0.87); }

.keyboard-key.default-key:focus, .keyboard-key.default-key:hover, .keyboard-key.default-key:checked { background-color: #333d42; color: #CFD8DC; transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1); }

.keyboard-key.default-key:active { background-color: #4a5459; color: #CFD8DC; transition-timing-function: cubic-bezier(0, 0, 0.2, 1); }

.keyboard-key.enter-key { background-color: #009688; background-image: url("key-enter.svg"); }

.keyboard-key.enter-key:focus, .keyboard-key.enter-key:hover, .keyboard-key.enter-key:checked { background-color: #1fa396; background-image: url("key-enter-active.svg"); }

.keyboard-key.enter-key:active { background-color: #00BCD4; background-image: url("key-enter-active.svg"); }

.keyboard-key.shift-key-lowercase { background-image: url("key-shift.svg"); }

.keyboard-key.shift-key-uppercase { background-image: url("key-shift-uppercase.svg"); }

.keyboard-key.shift-key-uppercase:focus, .keyboard-key.shift-key-uppercase:hover, .keyboard-key.shift-key-uppercase:checked { background-color: #1a3a41; }

.keyboard-key.shift-key-uppercase:active { background-color: #174d57; }

.keyboard-key.shift-key-uppercase:latched { background-image: url("key-shift-latched-uppercase.svg"); background-color: #1a3a41; transition-timing-function: cubic-bezier(0.4, 0, 0.2, 1); }

.keyboard-key.shift-key-uppercase:latched:focus, .keyboard-key.shift-key-uppercase:latched:hover { background-color: #174d57; }

.keyboard-key.hide-key { background-image: url("key-hide.svg"); }

.keyboard-key.layout-key { background-image: url("key-layout.svg"); }

.keyboard-subkeys { padding: 0; border-radius: 2px; -arrow-border-radius: 0; -arrow-background-color: transparent; -arrow-border-width: 0; -arrow-border-color: transparent; -arrow-base: 0; -arrow-rise: 0; -boxpointer-gap: 3.999; background-color: #009688; color: #FFFFFF; box-shadow: 0 2.5px 4.5px rgba(0, 0, 0, 0.34); }

.word-suggestions { font-size: 13pt; min-height: 1.6em; spacing: 3.999; font-weight: 500; }

.candidate-popup-content { padding: 0.5em; spacing: 0.3em; color: rgba(207, 216, 220, 0.54); }

.candidate-index { color: rgba(207, 216, 220, 0.87); }

.candidate-index:ltr { padding: 0.3em 0.5em 0.3em 0; }

.candidate-index:rtl { padding: 0.3em 0 0.3em 0.5em; }

.candidate-box { font-size: 11pt; padding: 0.3em 0.5em; border-radius: 2px; color: rgba(207, 216, 220, 0.87); transition-duration: 0s; }

.candidate-box:hover { background-color: rgba(207, 216, 220, 0.12); color: #CFD8DC; }

.candidate-box:hover .candidate-index { color: #CFD8DC; }

.candidate-box:active { background-color: rgba(207, 216, 220, 0.25); color: #CFD8DC; }

.candidate-box:active .candidate-index { color: #CFD8DC; }

.candidate-box:selected { background-color: #009688; color: #FFFFFF; }

.candidate-box:selected .candidate-index { color: rgba(207, 216, 220, 0.87); }

.candidate-page-button-box { height: 2em; }

.vertical .candidate-page-button-box { padding-top: 0.5em; }

.horizontal .candidate-page-button-box { padding-left: 0.5em; }

.candidate-page-button { padding: 4px; color: rgba(129, 196, 191, 0.87); }

.candidate-page-button:hover { background-color: rgba(77, 182, 172, 0.12); color: #81c4bf; }

.candidate-page-button:active { background-color: rgba(77, 182, 172, 0.25); color: #81c4bf; }

.candidate-page-button-previous { border-radius: 2px; border-right-width: 0; }

.candidate-page-button-next { border-radius: 2px; }

.candidate-page-button-icon { icon-size: 14px; }

.framed-user-icon { background-size: contain; border: none; color: #CFD8DC; border-radius: 2px; }

.framed-user-icon:hover { border-color: #CFD8DC; color: #CFD8DC; }

.login-dialog { border: none; background-color: transparent; }

.login-dialog-banner-view { max-width: 23em; padding-top: 24px; }

.login-dialog StEntry { border-color: transparent; background-color: rgba(0, 0, 0, 0.01); box-shadow: inset 0 -1px rgba(207, 216, 220, 0.2); color: #CFD8DC; selection-background-color: #00BCD4; selected-color: #FFFFFF; font-family: Noto Sans, Sans-Serif; transition-duration: 0s; }

.login-dialog StEntry:hover { border-color: transparent; box-shadow: inset 0 -2px rgba(207, 216, 220, 0.2); }

.login-dialog StEntry:focus { border-color: transparent; box-shadow: inset 0 -2px #00BCD4; }

.login-dialog StEntry:insensitive { border-color: transparent; color: rgba(207, 216, 220, 0.28); box-shadow: inset 0 -1px rgba(207, 216, 220, 0.056); color: rgba(207, 216, 220, 0.28); }

.login-dialog StEntry StIcon.capslock-warning { color: #FF9800; }

.login-dialog .modal-dialog-button-box { spacing: 1em; }

.login-dialog .modal-dialog-button { font-size: 11pt; border-color: transparent; color: rgba(207, 216, 220, 0.87); background-color: transparent; box-shadow: 0 0 transparent; text-shadow: none; icon-shadow: none; padding: 7px 16px 8px; font-weight: 500; }

.login-dialog .modal-dialog-button:hover, .login-dialog .modal-dialog-button:focus { border-color: transparent; color: #CFD8DC; background-color: rgba(207, 216, 220, 0.12); box-shadow: 0 0 transparent; text-shadow: none; icon-shadow: none; }

.login-dialog .modal-dialog-button:active { border-color: transparent; color: #FFFFFF; background-color: rgba(207, 216, 220, 0.25); box-shadow: 0 0 transparent; text-shadow: none; icon-shadow: none; }

.login-dialog .modal-dialog-button:insensitive { border-color: transparent; color: rgba(207, 216, 220, 0.2436); background-color: transparent; box-shadow: 0 0 transparent; text-shadow: none; icon-shadow: none; }

.login-dialog .modal-dialog-button:default { border-color: transparent; border-top: 1px solid rgba(255, 255, 255, 0.07); color: rgba(255, 255, 255, 0.87); background-color: #009688; box-shadow: 0 1px 2px rgba(0, 0, 0, 0.28); text-shadow: none; icon-shadow: none; }

.login-dialog .modal-dialog-button:default:hover, .login-dialog .modal-dialog-button:default:focus { border-color: transparent; border-top: 1px solid rgba(255, 255, 255, 0.07); color: #FFFFFF; background-color: #009688; box-shadow: 0 2.5px 4.5px rgba(0, 0, 0, 0.34); text-shadow: none; icon-shadow: none; }

.login-dialog .modal-dialog-button:default:active { border-color: transparent; border-top: 1px solid rgba(255, 255, 255, 0.07); color: #FFFFFF; background-color: #00BCD4; box-shadow: 0 2.5px 4.5px rgba(0, 0, 0, 0.34); text-shadow: none; icon-shadow: none; }

.login-dialog .modal-dialog-button:default:insensitive { border-color: transparent; color: rgba(207, 216, 220, 0.2436); background-color: rgba(207, 216, 220, 0.029232); box-shadow: 0 0 transparent; text-shadow: none; icon-shadow: none; }

.login-dialog-username, .user-widget-label { font-size: 12pt; color: #CFD8DC; font-weight: 700; text-align: left; }

.login-dialog-username:ltr, .user-widget-label:ltr { padding-left: 1em; }

.login-dialog-username:rtl, .user-widget-label:rtl { padding-right: 1em; }

.login-dialog-logo-bin { padding: 24px 0; }

.login-dialog-banner { color: rgba(207, 216, 220, 0.87); }

.login-dialog-button-box { spacing: 1em; }

.login-dialog-message-warning { color: #FF9800; }

.login-dialog-message-hint { padding-top: 0; padding-bottom: 20px; color: rgba(207, 216, 220, 0.54); }

.login-dialog-user-selection-box { padding: 100px 0; }

.login-dialog-not-listed-button { margin: 12px 0 0; }

.login-dialog-not-listed-button:ltr { margin-right: 4px; }

.login-dialog-not-listed-button:rtl { margin-left: 4px; }

.login-dialog-not-listed-label { font-size: 9pt; padding: 4px 0 5px; border-radius: 2px; color: rgba(129, 196, 191, 0.87); font-weight: 500; text-align: center; }

.login-dialog-not-listed-button:focus .login-dialog-not-listed-label { color: #81c4bf; background-color: rgba(0, 0, 0, 0.01); box-shadow: inset 0 0 0 2px rgba(77, 182, 172, 0.25); }

.login-dialog-not-listed-button:hover .login-dialog-not-listed-label { color: #81c4bf; background-color: rgba(77, 182, 172, 0.12); }

.login-dialog-not-listed-button:active .login-dialog-not-listed-label { color: #81c4bf; background-color: rgba(77, 182, 172, 0.25); box-shadow: 0 0 transparent; }

.login-dialog-user-list { width: 23em; spacing: 12px; }

.login-dialog-user-list:expanded .login-dialog-user-list-item:selected, .login-dialog-user-list:expanded .login-dialog-user-list-item:selected:focus { background-color: rgba(0, 0, 0, 0.01); box-shadow: inset 0 0 0 2px rgba(0, 188, 212, 0.2); }

.login-dialog-user-list:expanded .login-dialog-user-list-item:selected:hover, .login-dialog-user-list:expanded .login-dialog-user-list-item:selected:hover:focus { background-color: rgba(0, 188, 212, 0.12); }

.login-dialog-user-list:expanded .login-dialog-user-list-item:selected:active, .login-dialog-user-list:expanded .login-dialog-user-list-item:selected:active:focus { background-color: rgba(0, 188, 212, 0.25); }

.login-dialog-user-list:expanded .login-dialog-user-list-item:logged-in { border-radius: 0; background-color: rgba(0, 188, 212, 0.25); }

.login-dialog-user-list:expanded .login-dialog-user-list-item:logged-in:focus, .login-dialog-user-list:expanded .login-dialog-user-list-item:logged-in:hover { background-color: rgba(84, 199, 215, 0.155); }

.login-dialog-user-list:expanded .login-dialog-user-list-item:logged-in:active { background-color: rgba(91, 200, 216, 0.1875); }

.login-dialog-user-list:expanded .login-dialog-user-list-item:logged-in:ltr { box-shadow: inset 4px 0 #00BCD4; }

.login-dialog-user-list:expanded .login-dialog-user-list-item:logged-in:rtl { box-shadow: inset -4px 0 #00BCD4; }

.login-dialog-user-list-view { -st-vfade-offset: 0; }

.login-dialog-user-list-item { padding: 4px 4px 0; border-radius: 2px; transition-duration: 0.1s; }

.login-dialog-user-list-item:ltr .user-widget { padding-right: 1em; }

.login-dialog-user-list-item:rtl .user-widget { padding-left: 1em; }

.login-dialog-user-list-item .login-dialog-username, .login-dialog-user-list-item .user-widget-label { color: rgba(207, 216, 220, 0.87); }

.login-dialog-user-list-item:focus { background-color: rgba(0, 0, 0, 0.01); box-shadow: inset 0 0 0 2px rgba(207, 216, 220, 0.2); }

.login-dialog-user-list-item:hover { background-color: rgba(207, 216, 220, 0.12); }

.login-dialog-user-list-item:active { background-color: rgba(207, 216, 220, 0.25); }

.login-dialog-user-list-item:selected, .login-dialog-user-list-item:selected:focus { background-color: rgba(0, 0, 0, 0.01); box-shadow: inset 0 0 0 2px rgba(0, 188, 212, 0.2); }

.login-dialog-user-list-item:selected:hover, .login-dialog-user-list-item:selected:hover:focus { background-color: rgba(0, 188, 212, 0.12); }

.login-dialog-user-list-item:selected:active, .login-dialog-user-list-item:selected:active:focus { background-color: rgba(0, 188, 212, 0.25); }

.login-dialog-user-list-item:focus .login-dialog-username, .login-dialog-user-list-item:focus .user-widget-label, .login-dialog-user-list-item:hover .login-dialog-username, .login-dialog-user-list-item:hover .user-widget-label, .login-dialog-user-list-item:active .login-dialog-username, .login-dialog-user-list-item:active .user-widget-label { color: #CFD8DC; }

.login-dialog-user-list-item:selected .login-dialog-username, .login-dialog-user-list-item:selected .user-widget-label, .login-dialog-user-list-item:selected:focus .login-dialog-username, .login-dialog-user-list-item:selected:focus .user-widget-label { color: #00BCD4; }

.login-dialog-user-list-item .login-dialog-timed-login-indicator { height: 4px; margin: 4px 0 0 0; background-color: rgba(77, 182, 172, 0.87); }

.login-dialog-user-list-item:focus .login-dialog-timed-login-indicator { background-color: #4DB6AC; }

.login-dialog-prompt-layout { width: 23em; spacing: 1em; padding-top: 24px; padding-bottom: 12px; }

.login-dialog-prompt-label { font-size: 10pt; padding-top: 1em; color: rgba(207, 216, 220, 0.54); }

.login-dialog-session-list-button { padding: 4px; border-radius: 100px; color: rgba(207, 216, 220, 0.87); }

.login-dialog-session-list-button:focus { color: #CFD8DC; background-color: rgba(0, 0, 0, 0.01); box-shadow: inset 0 0 0 2px rgba(207, 216, 220, 0.2); }

.login-dialog-session-list-button:hover { color: #CFD8DC; background-color: rgba(207, 216, 220, 0.12); }

.login-dialog-session-list-button:active { color: #FFFFFF; background-color: #00BCD4; }

.login-dialog-session-list-button StIcon { icon-size: 16px; }

.screen-shield-arrows { padding-bottom: 3em; }

.screen-shield-arrows Gjs_Arrow { width: 80px; height: 48px; -arrow-thickness: 12px; -arrow-shadow: none; color: #FFFFFF; }

.screen-shield-clock { padding-bottom: 1.5em; color: #CFD8DC; text-align: center; }

.screen-shield-clock-time { font-size: 84pt; font-weight: 300; text-shadow: 0 1px 2px rgba(0, 0, 0, 0.28); }

.screen-shield-clock-date { font-size: 13pt; font-weight: 700; text-shadow: 0 1px 2px rgba(0, 0, 0, 0.28); }

.screen-shield-notifications-container { max-height: 500px; spacing: 6px; width: 30em; background-color: transparent; }

.screen-shield-notifications-container .summary-notification-stack-scrollview { padding-top: 0; padding-bottom: 0; }

.screen-shield-notifications-container .notification, .screen-shield-notifications-container .screen-shield-notification-source { padding: 12px 6px; border: none; border-radius: 2px; background-color: rgba(34, 45, 50, 0.9); color: #CFD8DC; }

.screen-shield-notifications-container .notification { margin-right: 15px; }

.screen-shield-notification-label { padding: 0 0 0 12px; font-weight: 700; }

.screen-shield-notification-count-text { padding: 0 0 0 12px; }

.screen-shield-background { background: black; box-shadow: 0 14px 19px rgba(0, 0, 0, 0.5); }

#lockDialogGroup { background: #222d32 url("noise-texture.png"); background-repeat: repeat; }

#screenShieldNotifications StButton#vhandle, #screenShieldNotifications StButton#hhandle { background-color: rgba(207, 216, 220, 0.297); }

#screenShieldNotifications StButton#vhandle:hover, #screenShieldNotifications StButton#hhandle:hover { background-color: rgba(207, 216, 220, 0.4785); }

#screenShieldNotifications StButton#vhandle:active, #screenShieldNotifications StButton#hhandle:active { background-color: #CFD8DC; }

#LookingGlassDialog { spacing: 4px; padding: 0; border: none; border-radius: 2px; background-color: rgba(34, 45, 50, 0.9); color: #CFD8DC; box-shadow: 0 10px 14px rgba(0, 0, 0, 0.44); }

#LookingGlassDialog > #Toolbar { padding: 0 6px; border: none; border-radius: 0; background-color: #222d32; box-shadow: 0 1px 2px rgba(0, 0, 0, 0.28); }

#LookingGlassDialog > #Toolbar > StIcon { padding: 4px 3px 2px; }

#LookingGlassDialog .labels { spacing: 0; }

#LookingGlassDialog .notebook-tab { font-size: 9pt; min-height: 30px; padding: 0 12px; color: rgba(207, 216, 220, 0.87); font-family: Roboto, Noto Sans, Sans-Serif; font-weight: 700; transition-duration: 0.15s; }

#LookingGlassDialog .notebook-tab:hover { border-bottom-width: 0; border-color: transparent; background-color: rgba(0, 0, 0, 0.01); color: #CFD8DC; box-shadow: inset 0 -2px rgba(207, 216, 220, 0.2); text-shadow: none; transition-duration: 0.15s; }

#LookingGlassDialog .notebook-tab:selected { border-bottom-width: 0; border-color: transparent; background-color: rgba(0, 0, 0, 0.01); color: #FFFFFF; box-shadow: inset 0 -2px #00BCD4; text-shadow: none; transition-duration: 0.15s; }

#LookingGlassDialog .notebook-tab StLabel { padding-bottom: 0.1em; }

#LookingGlassDialog StBoxLayout#EvalBox { padding: 4px; spacing: 4px; }

#LookingGlassDialog StBoxLayout#ResultsArea { spacing: 4px; }

.lg-dialog StEntry { selection-background-color: #00BCD4; selected-color: #FFFFFF; box-shadow: inset 0 -1px rgba(207, 216, 220, 0.2); }

.lg-dialog StEntry:hover { color: #FFFFFF; box-shadow: inset 0 -2px rgba(207, 216, 220, 0.2); }

.lg-dialog StEntry:focus { color: #FFFFFF; box-shadow: inset 0 -2px #00BCD4; }

.lg-dialog .shell-link { color: #55bcea; }

.lg-dialog .shell-link:hover { color: #55bcea; }

.lg-completions-text { font-size: 9pt; color: rgba(207, 216, 220, 0.87); font-style: italic; }

.lg-obj-inspector-title { spacing: 4px; }

.lg-obj-inspector-button { border-color: transparent; border-top: 1px solid rgba(255, 255, 255, 0.07); color: rgba(207, 216, 220, 0.87); background-color: #263238; box-shadow: 0 1px 2px rgba(0, 0, 0, 0.28); text-shadow: none; icon-shadow: none; padding: 4px; border-radius: 2px; background-color: #009688; color: rgba(255, 255, 255, 0.87); font-weight: 500; }

.lg-obj-inspector-button:hover, .lg-obj-inspector-button:focus { border-color: transparent; border-top: 1px solid rgba(255, 255, 255, 0.07); color: #CFD8DC; background-color: #263238; box-shadow: 0 2.5px 4.5px rgba(0, 0, 0, 0.34); text-shadow: none; icon-shadow: none; background-color: #009688; color: #FFFFFF; }

.lg-obj-inspector-button:active { border-color: transparent; border-top: 1px solid rgba(255, 255, 255, 0.07); color: #FFFFFF; background-color: #263238; box-shadow: 0 2.5px 4.5px rgba(0, 0, 0, 0.34); text-shadow: none; icon-shadow: none; background-color: #00BCD4; color: #FFFFFF; }

.lg-obj-inspector-button:insensitive { border-color: transparent; color: rgba(207, 216, 220, 0.2436); background-color: transparent; box-shadow: 0 0 transparent; text-shadow: none; icon-shadow: none; color: rgba(207, 216, 220, 0.28); }

#lookingGlassExtensions { padding: 4px; }

.lg-extensions-list { padding: 4px; spacing: 6px; }

.lg-extension { padding: 4px; border: none; border-radius: 2px; }

.lg-extension-name { font-size: 15pt; font-weight: 700; }

.lg-extension-meta { spacing: 6px; }

#LookingGlassPropertyInspector { padding: 6px; border: 1px solid rgba(0, 0, 0, 0.13); background: #222d32; color: #CFD8DC; box-shadow: 0 0 transparent; }

#LookingGlassPropertyInspector:ltr { border-radius: 2px 0 0 2px; border-left-color: transparent; }

#LookingGlassPropertyInspector:rtl { border-radius: 0 2px 2px 0; border-right-color: transparent; }

.masterslider.smaller .masterlabel, .masterslider.smaller .slider { min-width: 14.2em; }

.popup-menu StScrollView.apps-menu { margin: 0 4px; border-style: solid; border-color: rgba(0, 0, 0, 0.13); }

.popup-menu StScrollView.apps-menu:ltr { padding: 0 0 0 8px; border-left-width: 1px; }

.popup-menu StScrollView.apps-menu:rtl { padding: 0 8px 0 0; border-right-width: 1px; }

.main-box { background-color: #28343a; }

.main-box .popup-menu:ltr { padding-right: 4px; }

.main-box .popup-menu:rtl { padding-left: 4px; }

.main-box .system-menu-action, .main-box .system-menu-action:focus, .main-box .system-menu-action:hover, .main-box .system-menu-action:active, .main-box .system-menu-action:checked { padding: 10px; }

.main-box StScrollView.apps-menu { margin-bottom: 4px; padding: 0; border-width: 1px; background-color: #263238; }

.main-box StScrollView.apps-menu StIcon { icon-size: 16px; }

.gnomenu-view-mode-box, .gnomenu-user-group-box { border-color: #212B30; background-color: #2f3d44; }

.gnomenu-view-mode-button:first-child, .gnomenu-view-mode-button:last-child, .gnomenu-user-group-button:first-child, .gnomenu-user-group-button:last-child { padding: 5px 0.6em 6px; border-color: #212B30; background-color: #2f3d44 !important; color: rgba(207, 216, 220, 0.87); box-shadow: 0 0 transparent; font-weight: 500; }

.gnomenu-view-mode-button:hover:first-child, .gnomenu-view-mode-button:hover:last-child, .gnomenu-user-group-button:hover:first-child, .gnomenu-user-group-button:hover:last-child, .gnomenu-view-mode-button:focus:first-child, .gnomenu-view-mode-button:focus:last-child, .gnomenu-user-group-button:focus:first-child, .gnomenu-user-group-button:focus:last-child { background-color: #425056 !important; color: #CFD8DC; }

.gnomenu-view-mode-button:active:first-child, .gnomenu-view-mode-button:active:last-child, .gnomenu-user-group-button:active:first-child, .gnomenu-user-group-button:active:last-child { background-color: #57646a !important; color: #CFD8DC; }

.gnomenu-view-mode-button:checked:first-child, .gnomenu-view-mode-button:checked:last-child, .gnomenu-user-group-button:checked:first-child, .gnomenu-user-group-button:checked:last-child { background-color: #00BCD4 !important; color: #FFFFFF !important; }

.gnomenu-view-mode-button:insensitive:first-child, .gnomenu-view-mode-button:insensitive:last-child, .gnomenu-user-group-button:insensitive:first-child, .gnomenu-user-group-button:insensitive:last-child { background-color: #2f3d44; color: rgba(207, 216, 220, 0.28); }

#gnomenuMenuMainbox, #gnomenuMenuMainbox > * { transition-duration: 0s; }

#gnomenuMenuMainbox StEntry, #gnomenuMenuMainbox StEntry:focus { min-height: 0; padding: 5px 0.6em 6px; border-color: #212B30; background-color: #2f3d44; box-shadow: 0 0 transparent; }

.gnomenu-selected-app-title { color: rgba(207, 216, 220, 0.87); }

.gnomenu-selected-app-description { color: rgba(207, 216, 220, 0.54); }

.openweather-button, .openweather-menu-button-container, .openweather-button-box, .openweather-provider { color: rgba(207, 216, 220, 0.87); }

.openweather-button:hover, .openweather-menu-button-container:hover, .openweather-button-box:hover, .openweather-provider:hover { color: #CFD8DC; background-color: rgba(207, 216, 220, 0.12); }

.openweather-button:hover > StIcon, .openweather-menu-button-container:hover > StIcon, .openweather-button-box:hover > StIcon, .openweather-provider:hover > StIcon { color: #CFD8DC; }

.openweather-button:active, .openweather-button:focus, .openweather-menu-button-container:active, .openweather-menu-button-container:focus, .openweather-button-box:active, .openweather-button-box:focus, .openweather-provider:active, .openweather-provider:focus { color: #CFD8DC; background-color: rgba(207, 216, 220, 0.25); }

.openweather-button:active > StIcon, .openweather-button:focus > StIcon, .openweather-menu-button-container:active > StIcon, .openweather-menu-button-container:focus > StIcon, .openweather-button-box:active > StIcon, .openweather-button-box:focus > StIcon, .openweather-provider:active > StIcon, .openweather-provider:focus > StIcon { color: #CFD8DC; }

.openweather-button > StIcon, .openweather-button > StLabel, .openweather-menu-button-container > StIcon, .openweather-menu-button-container > StLabel, .openweather-button-box > StIcon, .openweather-button-box > StLabel, .openweather-provider > StIcon, .openweather-provider > StLabel { color: rgba(207, 216, 220, 0.87); }

.openweather-current-icon, .openweather-current-summary, .openweather-current-summarybox { color: #CFD8DC; }

.openweather-current-databox-values { color: rgba(207, 216, 220, 0.54); }

.openweather-current-databox-captions { color: rgba(207, 216, 220, 0.54); }

.openweather-forecast-icon, .openweather-forecast-summary { color: rgba(207, 216, 220, 0.87); }

.openweather-forecast-day, .openweather-forecast-temperature { color: rgba(207, 216, 220, 0.54); }

.openweather-sunrise-icon, .openweather-sunset-icon, .openweather-build-icon { color: rgba(207, 216, 220, 0.87); }

#dashtodockContainer { background: transparent; }

#dashtodockContainer #dash, #dashtodockContainer:overview #dash, #dashtodockContainer.extended #dash, #dashtodockContainer.extended:overview #dash { padding: 0; border: none; transition-duration: 0.4s; }

#dashtodockContainer.top #dash, #dashtodockContainer.top:overview #dash { border-radius: 0 0 2px 2px; }

#dashtodockContainer.top.extended #dash, #dashtodockContainer.top.extended:overview #dash { border-radius: 0; }

#dashtodockContainer.bottom #dash, #dashtodockContainer.bottom:overview #dash { border-radius: 2px 2px 0 0; }

#dashtodockContainer.bottom.extended #dash, #dashtodockContainer.bottom.extended:overview #dash { border-radius: 0; }

#dashtodockContainer.left #dash, #dashtodockContainer.left:overview #dash { border-radius: 0 2px 2px 0; }

#dashtodockContainer.left.extended #dash, #dashtodockContainer.left.extended:overview #dash { border-radius: 0; }

#dashtodockContainer.right #dash, #dashtodockContainer.right:overview #dash { border-radius: 2px 0 0 2px; }

#dashtodockContainer.right.extended #dash, #dashtodockContainer.right.extended:overview #dash { border-radius: 0; }

#dashtodockContainer #dash { background-color: #13191c; box-shadow: 0 0 transparent; }

#dashtodockContainer.opaque #dash { background-color: #13191c; box-shadow: inset 0 0 0 9999px #13191c; }

#dashtodockContainer.transparent #dash { background-color: rgba(19, 25, 28, 0.01); box-shadow: inset 0 0 0 9999px rgba(19, 25, 28, 0.34); }

#dashtodockContainer:overview #dash { background-color: rgba(207, 216, 220, 0.12); box-shadow: 0 0 transparent; }

#dashtodockContainer.opaque:overview #dash, #dashtodockContainer.transparent:overview #dash { background-color: rgba(19, 25, 28, 0.01); box-shadow: inset 0 0 0 9999px rgba(207, 216, 220, 0.12); }

#dashtodockContainer.extended:overview #dash, #dashtodockContainer.opaque.extended:overview #dash, #dashtodockContainer.transparent.extended:overview #dash { background-color: rgba(19, 25, 28, 0.01); box-shadow: 0 0 transparent; }

#dashtodockContainer .app-well-app .overview-icon, #dashtodockContainer .show-apps .overview-icon { padding: 9px; background-size: contain; }

#dashtodockContainer .dash-item-container { background: transparent; }

#dashtodockContainer .dash-item-container > StWidget { background-size: contain; }

#dashtodockContainer .number-overlay, #dashtodockContainer .notification-badge { min-width: 1.4em; min-height: 1.4em; margin: 0; padding: 0; border-radius: 100px; font-weight: 700; text-align: center; box-shadow: 0 2.5px 4.5px rgba(0, 0, 0, 0.34); }

#dashtodockContainer .number-overlay { background-color: #222d32; color: #FFFFFF; }

#dashtodockContainer .notification-badge { background-color: #009688; color: #FFFFFF; }

#dashtodockContainer.top .dash-item-container > StWidget.focused .overview-icon, #dashtodockContainer.extended.top .dash-item-container > StWidget.focused .overview-icon { border-radius: 0; background-color: rgba(207, 216, 220, 0.12); }

#dashtodockContainer.top .dash-item-container > StWidget.focused:hover .overview-icon, #dashtodockContainer.extended.top .dash-item-container > StWidget.focused:hover .overview-icon { border-radius: 0; background-color: rgba(207, 216, 220, 0.25); }

#dashtodockContainer.bottom .dash-item-container > StWidget.focused .overview-icon, #dashtodockContainer.extended.bottom .dash-item-container > StWidget.focused .overview-icon { border-radius: 0; background-color: rgba(207, 216, 220, 0.12); }

#dashtodockContainer.bottom .dash-item-container > StWidget.focused:hover .overview-icon, #dashtodockContainer.extended.bottom .dash-item-container > StWidget.focused:hover .overview-icon { border-radius: 0; background-color: rgba(207, 216, 220, 0.25); }

#dashtodockContainer.left .dash-item-container > StWidget.focused .overview-icon, #dashtodockContainer.extended.left .dash-item-container > StWidget.focused .overview-icon { border-radius: 0; background-color: rgba(207, 216, 220, 0.12); }

#dashtodockContainer.left .dash-item-container > StWidget.focused:hover .overview-icon, #dashtodockContainer.extended.left .dash-item-container > StWidget.focused:hover .overview-icon { border-radius: 0; background-color: rgba(207, 216, 220, 0.25); }

#dashtodockContainer.right .dash-item-container > StWidget.focused .overview-icon, #dashtodockContainer.extended.right .dash-item-container > StWidget.focused .overview-icon { border-radius: 0; background-color: rgba(207, 216, 220, 0.12); }

#dashtodockContainer.right .dash-item-container > StWidget.focused:hover .overview-icon, #dashtodockContainer.extended.right .dash-item-container > StWidget.focused:hover .overview-icon { border-radius: 0; background-color: rgba(207, 216, 220, 0.25); }

#panel.dashtopanelMainPanel.dashtopanelTop #panelLeft:hover, #panel.dashtopanelMainPanel.dashtopanelTop #panelCenter:hover, #panel.dashtopanelMainPanel.dashtopanelTop .panel-corner:hover, #panel.dashtopanelMainPanel.dashtopanelTop .panel-button:hover { box-shadow: inset 0 2px rgba(207, 216, 220, 0.2); }

#panel.dashtopanelMainPanel.dashtopanelTop #panelLeft:active, #panel.dashtopanelMainPanel.dashtopanelTop #panelLeft:focus, #panel.dashtopanelMainPanel.dashtopanelTop #panelLeft:checked, #panel.dashtopanelMainPanel.dashtopanelTop #panelLeft:overview, #panel.dashtopanelMainPanel.dashtopanelTop #panelCenter:active, #panel.dashtopanelMainPanel.dashtopanelTop #panelCenter:focus, #panel.dashtopanelMainPanel.dashtopanelTop #panelCenter:checked, #panel.dashtopanelMainPanel.dashtopanelTop #panelCenter:overview, #panel.dashtopanelMainPanel.dashtopanelTop .panel-corner:active, #panel.dashtopanelMainPanel.dashtopanelTop .panel-corner:focus, #panel.dashtopanelMainPanel.dashtopanelTop .panel-corner:checked, #panel.dashtopanelMainPanel.dashtopanelTop .panel-corner:overview, #panel.dashtopanelMainPanel.dashtopanelTop .panel-button:active, #panel.dashtopanelMainPanel.dashtopanelTop .panel-button:focus, #panel.dashtopanelMainPanel.dashtopanelTop .panel-button:checked, #panel.dashtopanelMainPanel.dashtopanelTop .panel-button:overview { box-shadow: inset 0 2px #00BCD4; }

#panel.dashtopanelMainPanel.dashtopanelTop .app-well-app .overview-icon, #panel.dashtopanelMainPanel.dashtopanelTop .show-apps .overview-icon { border-radius: 0; }

#panel.dashtopanelMainPanel.dashtopanelTop .app-well-app:focus .overview-icon, #panel.dashtopanelMainPanel.dashtopanelTop .app-well-app:hover .overview-icon, #panel.dashtopanelMainPanel.dashtopanelTop .app-well-app:active .overview-icon, #panel.dashtopanelMainPanel.dashtopanelTop .show-apps:focus .overview-icon, #panel.dashtopanelMainPanel.dashtopanelTop .show-apps:hover .overview-icon, #panel.dashtopanelMainPanel.dashtopanelTop .show-apps:active .overview-icon { border-radius: 0; background-color: rgba(0, 0, 0, 0.01); box-shadow: inset 0 2px rgba(207, 216, 220, 0.2); }

#panel.dashtopanelMainPanel.dashtopanelTop .app-well-app:checked .overview-icon, #panel.dashtopanelMainPanel.dashtopanelTop .show-apps:checked .overview-icon { box-shadow: inset 0 2px #00BCD4; }

#panel.dashtopanelMainPanel.dashtopanelTop #dashtopanelScrollview { padding: 0; }

#panel.dashtopanelMainPanel.dashtopanelTop #dashtopanelScrollview .app-well-app:focus .overview-icon, #panel.dashtopanelMainPanel.dashtopanelTop #dashtopanelScrollview .app-well-app:hover .overview-icon, #panel.dashtopanelMainPanel.dashtopanelTop #dashtopanelScrollview .app-well-app:active .overview-icon, #panel.dashtopanelMainPanel.dashtopanelTop #dashtopanelScrollview .show-apps:focus .overview-icon, #panel.dashtopanelMainPanel.dashtopanelTop #dashtopanelScrollview .show-apps:hover .overview-icon, #panel.dashtopanelMainPanel.dashtopanelTop #dashtopanelScrollview .show-apps:active .overview-icon { background-color: rgba(207, 216, 220, 0.12); box-shadow: 0 0 transparent; }

#panel.dashtopanelMainPanel.dashtopanelTop #dashtopanelScrollview .app-well-app:checked .overview-icon, #panel.dashtopanelMainPanel.dashtopanelTop #dashtopanelScrollview .show-apps:checked .overview-icon { background-color: rgba(0, 0, 0, 0.01); box-shadow: 0 0 transparent; }

#panel.dashtopanelMainPanel.dashtopanelTop .show-apps:checked .show-apps-icon, #panel.dashtopanelMainPanel.dashtopanelTop .show-apps:checked:hover .show-apps-icon { color: #FFFFFF; }

#panel.dashtopanelMainPanel.dashtopanelBottom #panelLeft:hover, #panel.dashtopanelMainPanel.dashtopanelBottom #panelCenter:hover, #panel.dashtopanelMainPanel.dashtopanelBottom .panel-corner:hover, #panel.dashtopanelMainPanel.dashtopanelBottom .panel-button:hover { box-shadow: inset 0 -2px rgba(207, 216, 220, 0.2); }

#panel.dashtopanelMainPanel.dashtopanelBottom #panelLeft:active, #panel.dashtopanelMainPanel.dashtopanelBottom #panelLeft:focus, #panel.dashtopanelMainPanel.dashtopanelBottom #panelLeft:checked, #panel.dashtopanelMainPanel.dashtopanelBottom #panelLeft:overview, #panel.dashtopanelMainPanel.dashtopanelBottom #panelCenter:active, #panel.dashtopanelMainPanel.dashtopanelBottom #panelCenter:focus, #panel.dashtopanelMainPanel.dashtopanelBottom #panelCenter:checked, #panel.dashtopanelMainPanel.dashtopanelBottom #panelCenter:overview, #panel.dashtopanelMainPanel.dashtopanelBottom .panel-corner:active, #panel.dashtopanelMainPanel.dashtopanelBottom .panel-corner:focus, #panel.dashtopanelMainPanel.dashtopanelBottom .panel-corner:checked, #panel.dashtopanelMainPanel.dashtopanelBottom .panel-corner:overview, #panel.dashtopanelMainPanel.dashtopanelBottom .panel-button:active, #panel.dashtopanelMainPanel.dashtopanelBottom .panel-button:focus, #panel.dashtopanelMainPanel.dashtopanelBottom .panel-button:checked, #panel.dashtopanelMainPanel.dashtopanelBottom .panel-button:overview { box-shadow: inset 0 -2px #00BCD4; }

#panel.dashtopanelMainPanel.dashtopanelBottom .app-well-app .overview-icon, #panel.dashtopanelMainPanel.dashtopanelBottom .show-apps .overview-icon { border-radius: 0; }

#panel.dashtopanelMainPanel.dashtopanelBottom .app-well-app:focus .overview-icon, #panel.dashtopanelMainPanel.dashtopanelBottom .app-well-app:hover .overview-icon, #panel.dashtopanelMainPanel.dashtopanelBottom .app-well-app:active .overview-icon, #panel.dashtopanelMainPanel.dashtopanelBottom .show-apps:focus .overview-icon, #panel.dashtopanelMainPanel.dashtopanelBottom .show-apps:hover .overview-icon, #panel.dashtopanelMainPanel.dashtopanelBottom .show-apps:active .overview-icon { border-radius: 0; background-color: rgba(0, 0, 0, 0.01); box-shadow: inset 0 -2px rgba(207, 216, 220, 0.2); }

#panel.dashtopanelMainPanel.dashtopanelBottom .app-well-app:checked .overview-icon, #panel.dashtopanelMainPanel.dashtopanelBottom .show-apps:checked .overview-icon { box-shadow: inset 0 -2px #00BCD4; }

#panel.dashtopanelMainPanel.dashtopanelBottom #dashtopanelScrollview { padding: 0; }

#panel.dashtopanelMainPanel.dashtopanelBottom #dashtopanelScrollview .app-well-app:focus .overview-icon, #panel.dashtopanelMainPanel.dashtopanelBottom #dashtopanelScrollview .app-well-app:hover .overview-icon, #panel.dashtopanelMainPanel.dashtopanelBottom #dashtopanelScrollview .app-well-app:active .overview-icon, #panel.dashtopanelMainPanel.dashtopanelBottom #dashtopanelScrollview .show-apps:focus .overview-icon, #panel.dashtopanelMainPanel.dashtopanelBottom #dashtopanelScrollview .show-apps:hover .overview-icon, #panel.dashtopanelMainPanel.dashtopanelBottom #dashtopanelScrollview .show-apps:active .overview-icon { background-color: rgba(207, 216, 220, 0.12); box-shadow: 0 0 transparent; }

#panel.dashtopanelMainPanel.dashtopanelBottom #dashtopanelScrollview .app-well-app:checked .overview-icon, #panel.dashtopanelMainPanel.dashtopanelBottom #dashtopanelScrollview .show-apps:checked .overview-icon { background-color: rgba(0, 0, 0, 0.01); box-shadow: 0 0 transparent; }

#panel.dashtopanelMainPanel.dashtopanelBottom .show-apps:checked .show-apps-icon, #panel.dashtopanelMainPanel.dashtopanelBottom .show-apps:checked:hover .show-apps-icon { color: #FFFFFF; }
