/* This file is part of adapta-gtk-theme Copyright (C) 2016-2018 Tista <tista.gma500@gmail.com> This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version. */
@keyframes ripple_effect { 0% { background-image: radial-gradient(circle farthest-corner at center, alpha(currentColor, 0.12) 0%, transparent 0%), image(alpha(currentColor, 0)); }
  66% { background-image: radial-gradient(circle farthest-corner at center, alpha(currentColor, 0.12) 100%, transparent 0%), image(alpha(currentColor, 0.12)); }
  100% { background-image: radial-gradient(circle farthest-corner at center, alpha(currentColor, 0.12) 100%, transparent 0%), image(alpha(currentColor, 0)); } }

@keyframes flat_ripple_effect { 0% { background-image: radial-gradient(circle farthest-corner at center, alpha(currentColor, 0.12) 0%, transparent 0%), image(alpha(currentColor, 0.12)); }
  66% { background-image: radial-gradient(circle farthest-corner at center, alpha(currentColor, 0.12) 100%, transparent 0%), image(alpha(currentColor, 0.12)); }
  100% { background-image: radial-gradient(circle farthest-corner at center, alpha(currentColor, 0) 100%, transparent 0%), image(alpha(currentColor, 0.12)); } }

#XfceNotifyWindow buttonbox button { background-image: radial-gradient(circle farthest-corner at center, alpha(currentColor, 0) 100%, transparent 0%), image(alpha(currentColor, 0)); box-shadow: none; transition-timing-function: cubic-bezier(0, 0, 0.2, 1); transition-duration: 0.2s; }

#XfceNotifyWindow buttonbox button:hover { background-image: radial-gradient(circle farthest-corner at center, alpha(currentColor, 0) 100%, transparent 0%), image(alpha(currentColor, 0.12)); box-shadow: none; }

#XfceNotifyWindow buttonbox button:active { box-shadow: none; transition: all 0.2s cubic-bezier(0, 0, 0.2, 1), background-image 0s; animation: flat_ripple_effect 0.3s cubic-bezier(0, 0, 0.2, 1) forwards; }

#XfceNotifyWindow buttonbox button:checked { box-shadow: none; }

#XfceNotifyWindow buttonbox button:disabled { box-shadow: none; }

#XfceNotifyWindow buttonbox button:disabled > label { color: inherit; }

/******************* Xfce-Notify-4.0 * */
#XfceNotifyWindow, #XfceNotifyWindow:hover { border-radius: 2px; border: 1px solid #222d32; color: #CFD8DC; background-color: rgba(34, 45, 50, 0.9); box-shadow: none; }

#XfceNotifyWindow box.vertical > label#summary { color: #CFD8DC; font-weight: 700; }

#XfceNotifyWindow box.vertical > label#body { color: rgba(207, 216, 220, 0.87); }

#XfceNotifyWindow buttonbox button { background-color: transparent; }

#XfceNotifyWindow buttonbox button:not(:active):not(:disabled):not(hover) { background-color: transparent; color: rgba(129, 196, 191, 0.87); }

#XfceNotifyWindow buttonbox button:hover { background-color: transparent; color: #81c4bf; }

#XfceNotifyWindow buttonbox button:active { border-image: none; background-color: transparent; color: #81c4bf; box-shadow: none; }

#XfceNotifyWindow buttonbox button:checked { border-image: none; background-color: transparent; color: #81c4bf; box-shadow: none; }

#XfceNotifyWindow buttonbox button:disabled { background-color: transparent; color: rgba(129, 196, 191, 0.4); }

#XfceNotifyWindow progressbar { min-width: 4px; min-height: 4px; }

#XfceNotifyWindow progressbar trough { border-style: none; background-color: rgba(77, 182, 172, 0.2); box-shadow: none; }

#XfceNotifyWindow progressbar progress { border-style: none; border-radius: 0; background-image: none; background-color: #4DB6AC; }
