#
# Colour scheme
#
gtk-color-scheme = "base_color:#FFFFFF\nbg_color:#FAFBFC"
gtk-color-scheme = "text_color:#263238\nfg_color:#263238"
gtk-color-scheme = "selected_bg_color:#00BCD4\nselected_fg_color:#FFFFFF"
gtk-color-scheme = "tooltip_bg_color:#222D32\ntooltip_fg_color:#CFD8DC"
gtk-color-scheme = "link_color:#03A9F4\nvisited_link_color:#9C27B0"
gtk-color-scheme = "inverted_dark_color:#222D32\ninverted_fg_color:#CFD8DC"
gtk-color-scheme = "scroll_slider_color:#BEC2C3\nscroll_slider_prelight_color:#979D9F"
gtk-color-scheme = "panel_bg_color:#13191C"
gtk-color-scheme = "secondary_dark_color:#F7F9F9"
gtk-color-scheme = "solid_white:#FFFFFF"
gtk-color-scheme = "accent_color:#4DB6AC"
gtk-color-scheme = "light_color:#FFFFFF"


#
# Default Colours
#
style "default_colors" {
  text[NORMAL] = mix(0.87, @text_color, @base_color)
  text[PRELIGHT] = @text_color
  text[ACTIVE] = @selected_fg_color
  text[INSENSITIVE] = mix(0.28, @text_color, @base_color)
  text[SELECTED] = @selected_fg_color

  base[NORMAL] = @base_color
  base[PRELIGHT] = mix(0.5, @base_color, @bg_color)
  base[ACTIVE] = @selected_bg_color
  base[INSENSITIVE] = mix(0.5, @base_color, @bg_color)
  base[SELECTED] = @selected_bg_color

  fg[NORMAL] = mix(0.87, @fg_color, @bg_color)
  fg[PRELIGHT] = @fg_color
  fg[ACTIVE] = @fg_color
  fg[INSENSITIVE] = mix(0.28, @fg_color, @bg_color)
  fg[SELECTED] = @selected_fg_color

  bg[NORMAL] = @bg_color
  bg[PRELIGHT] = mix(0.1, @fg_color, @bg_color)
  bg[ACTIVE] = mix(0.2, @fg_color, @bg_color)
  bg[INSENSITIVE] = @bg_color
  bg[SELECTED] = @selected_bg_color
}
